#
# spec file for package dagger
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           dagger
Version:        0.9.3
Release:        1.1
Summary:        A portable devkit for CI/CD pipelines
License:        GPL-3.0-only
URL:            https://github.com/dagger/dagger
Source:         dagger-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.20

%description
Dagger is a portable devkit for CICD.

Using Dagger, software teams can develop powerful CICD pipelines with minimal effort, then run them anywhere. Benefits include:
* Unify dev and CI environments. Write your pipeline once, Dagger will run it the same everywhere.
* Reduce CI lock-in. No more re-writing everything from scratch every 6 months.

%prep
%autosetup -p 1 -a 1

%build
GOWORK=off go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/dagger ./cmd/dagger

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Mon Nov  6 2023 kastl@b1-systems.de
- Update to version 0.9.3:
  * release notes for v0.9.3 (#6060)
  * ci: update all github workflows to go 1.21 (#6059)
  * dagger call: add support for service arguments (#6028)
  * CLI: support git URLs as directory arguments (#6058)
  * engine: update to latest graphql-go version (#6056)
  * dagger call: fix returning a list of objects with functions
    (#6025)
  * fix: reduce verbosity of codegen errors (#6042)
  * dagger download: rename flag --export-path to --output (#6026)
  * Fix for annotated dagger types (#6037)
  * cli: handle more git remote cases in mod publish (#6053)
  * chore(deps-dev): bump uk.org.webcompere:system-stubs-jupiter
    (#6045)
  * zenith: set subpath and path when parent module is git (#6052)
  * chore: update x/net to v0.17.0 (#6040)
  * fix: remove comparable constraint from Optional (#6041)
  * docs: fix typo in method name (#6038)
  * cli: call asService if container provided to dagger up (#6039)
  * fix zenith call -m docs (#6036)
  * feat: support passing core type arrays to dagger call (#6030)
  * Improve releasing during v0.9.2 (#6027)
  * chore(deps): bump google.golang.org/grpc from 1.58.3 to 1.59.0
    (#6008)
* Tue Oct 31 2023 kastl@b1-systems.de
- Update to version 0.9.2:
  * Add v0.9.2 release notes (#6023)
  * Add support for custom objects in Python modules (#6016)
  * ci: improve test workflow runtimes (#6018)
  * cli: rename `use` command to `install`. (#6021)
  * Add DAGGER_CLOUD_TOKEN client-side so that we get telemetry in
    Cloud (#6020)
  * Fix for mod deps blowing up ID size (#6014)
  * add dagger mod publish (#5980)
  * codegen: close progrock writer (#6011)
  * core: disallow reserved ID field in user modules (#5995)
  * Add a backfill test for various styles of passing builtin
    IDable types (#5992)
  * chore(deps): bump github.com/google/uuid from 1.3.0 to 1.4.0
    (#6010)
  * Add nix package publishing to goreleaser config (#5996)
  * Add experimental GPU support (#5605)
  * Move python module codegen introspection to cli (#5997)
  * docs: Adds Tekton guide (#5970)
  * cli: fix handling of list input in dagger call (#5982)
  * chore: remove buildctl grpc build hack (#5985)
  * zenith: always run git exec ops when resolving refs (#5987)
  * zenith: use main as default go module name (#5983)
  * ci: update go from 1.21.2->1.21.3 (#5977)
  * dagger mod init creates LICENSE if none found (#5978)
* Thu Oct 26 2023 kastl@b1-systems.de
- Update to version 0.9.1:
  * Add v0.9.1 release notes (#5967)
  * chore: update grpc to v1.58.3 (#5965)
  * feat: allow querying gitref resolved commit (#5910)
  * feat: improve entries with include and recursive (#5824)
  * python: rename modules package (#5962)
  * Fix python module codegen (#5959)
  * Fix several validation and presentation issues in function
    commands (#5952)
  * core: use context.Context instead of core.Context (#5961)
  * cli: set source subpath when loading git modules (#5955)
  * chore: remove unneccessary secret store method (#5958)
  * fix: return upstream ErrNotFound from secret store (#5951)
  * docs: Fixes, dagger call additions, remove ext core types
    (#5956)
  * core: disable support for modules extending core types (#5954)
  * core: namespace module objects and function extensions (#5932)
  * core: fix huge module/func IDs by removing Function.call
    (#5947)
  * fix: do not fail when value set to file flag (#5948)
  * docs: Fix typo in cli install instructions. (#5946)
  * bump internal ci tooling to v0.9.0 (#5941)
* Sat Oct 21 2023 kastl@b1-systems.de
- Update to version 0.9.0:
  * ci: fix engine image publishing bugs (#5942)
  * chore: release notes for v0.9.0 (#5939)
  * ci: add --no-cache to alpine apk add (#5938)
  * Switch all workflows to Dagger Runners (#5936)
  * cli: handle optional arguments in module functions (#5934)
  * chore: backfill changie logs (#5935)
  * add `dagger up` command (#5931)
  * docs: Adds service code samples, updates cookbook (#5933)
  * Improve cli for calling module functions (#5882)
  * fix services v2 python snippets (#5929)
  * docs: Adds redirect URL for services guide (#5922)
  * engine: reduce connection retry noise (#5918)
  * core: support multiple cache configs for upstream remote cache
    (#5730)
  * hack/dev: add dagger to $PATH, add with-dev (#5925)
  * fix: don't output dagger generated types (unless overriding
    them) (#5926)
  * engine: unhide mod subcommands (#5923)
  * docs: explain how to configure the dagger engine (#5828)
  * Services v2: new API, c2h and h2c networking, start/stop
    support, run via gateway (#5557)
  * ci: use per-version python caches (#5919)
  * ci: pin buildctl source image to multiplatform index (#5916)
  * docs: Makes minor change to inline code refs (#5899)
  * Fix trivy scan failures w/ otel upgrades (#5906)
  * feat: fail when connecting to vanilla buildkit (#5892)
  * docs: Adds Argo Workflows to Cloud guide (#5884)
  * chore(deps): bump sass from 1.66.1 to 1.69.3 in /website
    (#5898)
  * docs(feat): mark deprecated args in graphql reference (#5895)
  * fix(docs): remove duplicated graphql api section (#5897)
  * cli: reveal errored vertices by default (#5896)
  * core: document docker-image:// in operator manual (#5890)
  * chore(deps): bump golang.org/x/oauth2 from 0.11.0 to 0.13.0
    (#5858)
  * docs: Update curl commands (#5888)
  * delete the daggerverse (#5889)
  * chore(deps): bump golang.org/x/crypto from 0.13.0 to 0.14.0
    (#5859)
  * fix: fix Dagger.Container.with_env_variable/4 crash (#5837)
  * docs: explain rootless limitation and constraint (#5809)
  * docs(guides): updates examples of glob patterns supported in
    dagger (#5719)
  * engine: ensure blob source layers are unlazied. (#5885)
  * implement new conventions for IDable objects (#5881)
  * Change Daggerverse url (#5883)
  * chore: update buildkit to master@86e25b3ad8c2 (#5876)
* Thu Oct 12 2023 kastl@b1-systems.de
- Update to version 0.8.8:
  * Add v0.8.8 release notes (#5875)
  * feat: show graphql schema errors in context (#5874)
  * docs: update zenith build from source instructions (#5873)
  * chore: link zenith labs docs in zenith readme (#5868)
  * chore(deps): bump github.com/prometheus/procfs from 0.11.0 to
    0.12.0 (#5845)
  * docs: add concurrency guide to cookbook (#5833)
  * Zenith xrc2: revenge of the function (#5757)
  * fix: fix process hang when run with dagger run (#5712)
  * docs: Updates Zenith guide (#5855)
  * docs: Updates WithDirectory explanations (#5831)
  * docs: Adds Zenith guide (#5853)
  * docs: Moved token instructions (#5830)
  * docs: Improves dependency caching recipes (#5814)
  * docs: Improves explanation of caching and cache volumes (#5832)
  * chore: Apache 2.0 license note (#5835)
  * Improve schema (re)generation (#5826)
  * install.sh uses CloudFront CDN for CLI installs (#5829)
  * create argo-workflows guide (#5693)
  * chore: add engine logs for failed queries (#5827)
  * docs: fix indentation in GitHub Actions example (#5822)
  * docs: improve cookbook to share client session and modules with
    classes (#5810)
  * Fix typo in docker-engine-host JavaScript snippt=et (#5819)
  * docs: Adds Kubernetes guide (#5816)
  * engine: cache: fallback to local cache if remote cache returns
    an error (#5815)
  * Attempt to start engine container before return (#5811)
  * Fix helm chart publish (#5813)
  * Update BuildKit dependency to use upstream Wait (#5808)
  * Fix TestHTTP that relied on the existence of TESTING.md (#5812)
  * chore: remove refs to deprecated io/ioutil (#5801)
  * chore: update README and CONTRIBUTING guides (#5806)
  * docs: Adds Dagger CLI step to quickstart (#5807)
  * Dagger Engine Helm chart (#5505)
  * docs: Adds Dagger Cloud docs (#5802)
  * Improve releasing during v0.8.7 (#5800)
* Tue Sep 19 2023 kastl@b1-systems.de
- Update to version 0.8.7:
  * Add v0.8.7 release notes (#5798)
  * engine: remove syncedCacheMount check for cache manager (#5797)
  * Remove redundant return & go fmt
  * doc(codegen): document how to bump engine dependency
  * feat(codegen): add schema for dagger engine 0.8.3 and 0.8.4
  * fix(codegen): clarify codegen plugin parameters and Dagger
    version in generated code
  * fix: Fix NPE when CLI download fails and log error
  * fix(doc): fix javadoc for field parameters in generated code
  * fix: Add a static 'from' method to instanciate a Scalar from a
    String literal
  * fix: replace deprecated API calls in tests - Container.fs ->
    Container.rootfs - Container.exec -> Container.withExec
  * build: fix maven versions plugin groupId
  * fix: fix coding style for linter
  * build: Add schema for 0.6.4
  * fix: correctly return the dagger CLI path in codegen plugin and
    fix some log messages
  * build: set development version to 1.0.0-SNAPSHOT. Add "release"
    profile dedicated to deployment
  * build: add linter plugin and lint current code
  * build(codegen): add introspection query in the codegen plugin
    resources and use it when schema is not available. Inject the
    CLI version in the code at build time
  * build: rename package name from 'org.chelonix.dagger.*' to
    'io.dagger.*'
  * build: package jar with dependencies and upload artifacts in
    github (#11)
  * build(workflow): enable build on linux and macos (#9)
  * fix: client hangs on close (#8)
  * fix: support macos arm64 architure by cli downloader (#7)
  * feat(log): add debug log when response is contains errors. (#5)
  * fix: add missing sample in the sample code demo app (#4)
  * build: support dependency caching in github action (#3)
  * Clean up build process & better samples (#2)
  * Initial version (#1)
  * Initial commit
* Tue Sep 19 2023 kastl@b1-systems.de
- Update to version 0.8.6:
  * Add v0.8.6 release notes (#5794)
  * engine: record seen cache volumes at resolver level (#5786)
  * fix: GitLab labels (#5790)
  * Fix name of TUI experimental ENV variable (#5789)
  * chore(deps): bump github.com/rs/zerolog from 1.29.1 to 1.30.0
    (#5740)
  * chore(deps): bump go.opentelemetry.io/proto/otlp from 0.19.0 to
    1.0.0 (#5738)
* Thu Sep 14 2023 kastl@b1-systems.de
- Update to version 0.8.5:
  * Add v0.8.5 release notes (#5776)
  * Backport: services via gateway, minus API changes (#5764)
  * chore(deps): bump github.com/charmbracelet/lipgloss from 0.7.1
    to 0.8.0 (#5736)
  * chore(deps): bump @svgr/webpack from 8.0.1 to 8.1.0 in /website
    (#5735)
  * fix: engine CLI flags typo (#5761)
  * fix: panic if services DNS is disabled (#5760)
  * feat: extends mounted secret api (#5707)
  * engine: add DAGGERL_CLOUD_TOKEN env variable support (#5773)
  * chore(deps): bump typedoc-plugin-markdown in /website (#5731)
  * fix(docs): quickstart css selectors (#5624)
  * feat: Unify VCS labels + add Gitlab and CircleCI labels (#5705)
  * docs: Adds "dagger run" to Jenkins/Circle samples (#5703)
  * update go versions for go getting started step 5b (#5770)
  * docs: Adds cookbook recipe for shared client session and
    modules (#5721)
  * refactor: chip away at removing eyre (#5768)
  * docs: Adds subsections to FAQ (#5766)
  * feat: update rust dependencies (#5767)
  * Python: Add experimental default client (#5723)
  * tests: use `connect(t)` everywhere, send logs to `t.Log`
    (#5762)
  * docs: Removes dagger.WithWorkdir from examples (#5725)
  * chore(deps): bump sass from 1.64.2 to 1.66.1 in /website
    (#5732)
  * docs: Adds note and information on cache types and
    invalidations (#5718)
  * docs: Added "dagger run" to quickstart (#5702)
  * docs: Updates troubleshooting guide with networking problem and
    solution (#5717)
  * Re-enable dagger k8s runners (#5722)
  * chore: update release guide to remove rust. (#5720)
  * fix interactive TUI (#5681)
  * docs: Updates some guides to use "dagger run" (#5701)
  * feat: add rust to mage (#5709)
  * cli: allow to set secret session token in listen command
    (#5704)
  * docs: Adds host directory r/w example to guide and cookbook
    (#5619)
  * docs: Updated some guides to use "dagger run" (#5637)
  * Basic Project Zenith README (#5698)
  * Disable dagger-runner (#5692)
  * gha: fix yaml error in main push scan-engine (#5690)
  * Add trivy vulnerability scanning to GHA (#5683)
  * fix: cannot connect to Dagger Engine and always raise error
    (#5665)
  * feat: throw error when workdir config on session (#5689)
  * Updated examples link in repository README
  * Reorganized directories, updated README, deleted LICENSE
  * Moves content to examples sub-dir
  * core: update operator manual w/ how to config registry mirrors
    (#5684)
  * engine: update go.mod deps and engine image binaries to trim
    deps w/ CVEs (#5680)
  * fix: calling id for any optional arguments that is ID type
    (#5674)
  * feat: throw error on workdir config on session (#5675)
  * docs: Added Dockerfile build secrets example  (#5661)
  * docs: Added recipe to build Dockerfile with different build
    context directory (#5634)
  * docs: Updated OCI runtime guide (#5639)
  * docs: Added chainable callbacks guide (#5653)
  * docs: Added Tailscale access recipe to cookbook (#5532)
  * Improve releasing during v0.8.4 (#5658)
  * Add Pulumi example. (#33)
  * More core concepts! (#22)
  * Bump webpack from 5.75.0 to 5.76.1 in /nodejs/react-build (#20)
  * add core concepts section to readme
  * add python db service example
  * add nodejs db service example
  * add go db service example
  * update go examples to be chained
  * README
  * go: adds aws-cdk demo
  * Bump json5 from 1.0.1 to 1.0.2 in /nodejs/react-build
  * add published to in output text
  * convert memcached dockerfile to dagger pipeline
  * Add first nodejs, python, and bash examples (#12)
  * feat: New structure
  * reorder steps since no default url
  * simplfy output
  * update multiarch example concurrency
  * remove europa examples
  * add readme
  * do a tree after the dagger pipeline
  * unneeded closures
  * parallel builds
  * pass repo by cli arg
  * build something else
  * build darwin too
  * make flat files
  * multiarch build example
  * Reduce packages to essentials
  * Add cue.mod
  * Update README.md
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.8.4:
  * Add v0.8.4 release notes (#5656)
  * Run Engine tests in dev Engine (on top of stable Engine)
    (#5652)
  * fix: switch to stable engine only case no local cli (#5654)
  * core: default container tar export permissions to 0600 (#5649)
  * feat: support version compatibility check (#5577)
  * fix: NodeJS conflict between enumeration and string (#5645)
  * fix: fix connect always timeout (#5646)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.8.3:
  * Add v0.8.3 release notes (#5641)
  * docs: Updated some guides to use "dagger run" (#5604)
  * Fix utf8 labels causing hang, clean up + fix label collection
    in general (#5628)
  * feat: show export host target (#5632)
  * add changelogs for fixes (#5633)
  * core: export files with same permissions as source (#5629)
  * core: hide merge vertexes from output (#5630)
  * feat: add more logs on dagger loading (#5436)
  * Improve releasing during 0.8.2 (#5615)
  * docs: quickstart layout width auto-expands so that playground
    fits better (#5610)
  * fix: fix example query in dagger query (#5622)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.8.2:
  * Generate v0.8.2 release notes (#5612)
  * remote cache: improve http error checking (#5506)
  * Preserve git email anonymity (one-way hash) (#5611)
  * Add release note missed from previous PR (#5603)
  * telemetry: fix labels not being included (#5602)
  * docs: Added dagger run examples (#5529)
  * core: add integ test for dagger run and showing progress
    (#5582)
  * docs: Added cookbook examples for Git dir ops (#5599)
  * docs: Modified releases link to point to changelog (#5600)
  * docs: Added "dagger run" to get started guides (#5591)
  * docs: Updated some URLs to remove numeric ids (#5592)
  * Improve releasing during v0.8.0 (#5569)
  * chore: improve elixir bump version (#5527)
  * docs: Updated multiarch examples with `mediatypes` (#5556)
  * engine: fix combined cache manager to query local cache too.
    (#5585)
* Sun Aug  6 2023 kastl@b1-systems.de
- Update to version 0.8.1:
  * Generate v0.8.1 release notes (#5580)
  * engine: set version stamp on engine image builds (#5578)
  * core: fix setting image config during multiplatform
    export+publish (#5574)
  * engine: fix telemetry writer to use the correct vertex (#5573)
  * docs: Added pitfalls of host directories (#5509)
  * fix dagger run not showing command progress (#5564)
  * core: fix max file chunk size (#5570)
  * docs: cookbook: mount directories as secrets after v.0.8.0
    (#5520)
* Fri Aug  4 2023 kastl@b1-systems.de
- Update to version 0.8.0 (no releases between 0.6.4 and 0.8.0):
  * Create release notes for Engine & CLI v0.8.0 (#5563)
  * Add cookbook examples on error handling (#5538)
  * docs: updated CLI code snippet with latest API reference
    (#5554)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.7.0 to
    5.8.1 (#5545)
  * feat: Elixir codegen improvement (#5526)
  * docs: Added FAQ entries for upgrading/uninstalling (#5515)
  * build(deps): bump github.com/tidwall/gjson from 1.14.4 to
    1.15.0 (#5543)
  * build(deps): bump clsx from 1.2.1 to 2.0.0 in /website (#5549)
  * build(deps): bump google.golang.org/grpc from 1.55.0 to 1.57.0
    (#5541)
  * update golang.org/x/sys v0.0.0-20220811171246-fbc7d0a398ab to
    0.1.0 (#5528)
  * build(deps-dev): bump @trivago/prettier-plugin-sort-imports
    (#5546)
  * build(deps): bump golang.org/x/oauth2 from 0.9.0 to 0.10.0
    (#5547)
  * build(deps): bump sass from 1.63.6 to 1.64.2 in /website
    (#5550)
  * Python: restructure internal packages and modules (#5558)
  * Centralize graphql server in the engine runner (#5415)
  * feat: add support _EXPERIMENTAL_DAGGER_CLI_BIN to rust (#5534)
  * feat: check version compatibility (#5315)
  * Node.js: Fix returning lists of objects (#5523)
  * auth: always pass bearer auth related requests to docker auth
    provider. (#5524)
  * Node.js: Export `Client` as a named export, instead of default
    (#5517)
  * Python: add status updates during automatic provisioning
    (#5522)
  * feat: improve engine session loading logging (#5488)
  * Revert "docs: cookbook: mount directories as secrets (#5502)"
    (#5519)
  * docs: cookbook: mount directories as secrets (#5502)
  * feat: implement `host.setSecretFile()` to securely set binary
    files as secrets (#5500)
  * Python: Remove sync client (#5514)
  * engine: fix publish (#5516)
  * Remove API deprecations (#5512)
  * Rename `id` argument in `Container.withRootfs` (#5513)
  * Add missing types of changes: Breaking, Removed & Security
    (#5510)
  * Python: Enforce keyword usage for optional arguments (#5508)
  * engine: bump alpine image to fix dns resolution error (#5470)
  * Add release notes fragment instructions (#5501)
  * core: add test for cache volumes w/ submounts. (#5491)
  * Improve releasing during v0.6.4 (#5490)
  * chore: update AppendAnonymousGitLabels (#5487)
* Thu Jul 20 2023 kastl@b1-systems.de
- Update to version 0.6.4:
  * Prepare v0.6.4 release (#5486)
  * Add missing release notes (#5483)
  * Deprecate exitCode (#5481)
  * Update python dependencies (#5480)
  * Fix coroutines not showing in Python reference docs (#5477)
  * inline tui: show run duration at the end (#5476)
  * core: attempt to deflake container image load compat test.
    (#5473)
  * stabilize container hostnames against SessionID (#5474)
  * core: Add test for local imports across sessions (#5471)
  * core: support optionally setting explicit mediatypes (#5467)
  * Improve releasing during 0.6.3 (#5408)
  * core: add include/exclude name to host dir copy name (#5469)
  * build(deps): bump github.com/google/go-containerregistry
    (#5460)
  * build(deps): bump golang.org/x/mod in /internal/mage (#5466)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.5.2 to
    5.7.0 (#5459)
  * build(deps): bump golang.org/x/text from 0.10.0 to 0.11.0
    (#5458)
  * Start working on a code generation tool (#5422)
  * Fix VERSION variable for CLI install instructions (#5453)
  * build(deps): bump google.golang.org/grpc (#5411)
  * Fix corner case where WithDirectory included wrong contents.
    (#5448)
  * Container: add `withFocus`, `withoutFocus` (#5364)
  * Fix .mjs docs lint and format (#5435)
  * Cookbook: integrating with a docker engine (#5421)
  * Update 723462-use-secrets.md (#5409)
  * Add `File.sync` (#5416)
  * Add `Directory.sync` (#5414)
  * Replace `ExitCode` usage with `Sync` (#5418)
  * Replace deprecated API fields (#5419)
  * core: Remove unimplemented git fields (#5410)
  * core: Optimize *.WithDirectory and *.WithFile via MergeOp.
    (#5400)
* Wed Jul  5 2023 kastl@b1-systems.de
- Update to version 0.6.3:
  * docs: Added Azure Pipelines sample in CI guide (#5166)
  * Fix Python provision tests (#5403)
  * Python: migrate back to hatch (#5401)
  * bump github.com/Khan/genqlient from 0.5.0 to 0.6.0 (#5402)
  * build(deps): bump github.com/vito/progrock from 0.6.0 to 0.7.0
    (#5385)
  * build(deps): bump typescript from 4.9.5 to 5.0.4 in /website
    (#5394)
  * build(deps): bump golang.org/x/oauth2 from 0.8.0 to 0.9.0
    (#5387)
  * build(deps): bump github.com/prometheus/procfs from 0.10.1 to
    0.11.0 (#5384)
  * build(deps): bump sass from 1.61.0 to 1.63.6 in /website
    (#5393)
  * Fix returning lists of objects (#5375)
  * core: improve image publish/export format compatibility.
    (#5365)
  * project: update runtimes to use Dagger types. (#5360)
  * Fix hacks in project commands and sync (#5353)
  * engine: add cloud cache token env var (#5356)
  * engine: remove old cache config env from autoprovision. (#5355)
  * project: also kebab flag names. (#5354)
  * Python linting fixes (#5352)
  * Replace exitCode with sync in docs (#5327)
  * Fix failing tests due to outdated merge (#5350)
  * project: partial support for returning host dirs/files. (#5346)
  * project: convert camel command names to kebab (#5349)
  * cache: set dagger cloud default magicache URL (#5343)
  * cli: fix incorrect subcommand being called. (#5344)
  * Python Project Commands: Create thin wrapper around strawberry
    (#5300)
  * `dagger project` CLI (#5308)
  * core: use include filter in host.file (#5345)
  * Send Progrock updates to Cloud (#5297)
  * Improve releasing during 0.6.2 (#5325)
* Fri Jun 16 2023 kastl@b1-systems.de
- Update to version 0.6.2:
  * Host export support for project commands (#5157)
  * feat: add host file query (#5317)
  * Add link to releases on GitHub to sidebar (#5320)
  * build(deps): bump webpack (#5318)
  * fix(docs): increase guides tag search size (#5319)
  * interactive tui: fix follow (#5283)
  * Adds t.Parallel to auth, core and router tests (#5316)
  * ci: Use alpine for golangci-lint image (#5309)
  * build(deps): bump typedoc from 0.23.26 to 0.24.7 in /website
    (#5267)
  * Bump buildkit for ExecProcessServer mutex fix (#5312)
  * Merge exposed ports on From and Build (#5158)
  * Secret Scrub Multi Write (#5149)
  * ci: Fix lint-daggerized.yml error (#5244)
  * Simplify iterations for optional args in Go code (#5304)
  * First pass at spec for extensions + project command
    implementations. (#5190)
  * Fix metrics typo (#5302)
  * bump buildkit for unknown blob fix (#5298)
  * run tests with `gotestsum`, list slow tests (#5293)
  * docs: Added Java/Spring guide (#5212)
  * docs: Added AWS Lambda with zip files guide (#5202)
  * Fix flakiness in TestContainerExecError test (#5229)
  * docs: Added AWS CodePipeline guide (#5188)
  * docs: Added Azure Pipelines + Azure Container Instances guide
    (#5165)
  * show health-checks in progress UI (#5281)
  * dnsmasq: configure domain-needed (#5282)
  * build(deps): bump @svgr/webpack from 6.5.1 to 8.0.1 in /website
    (#5270)
  * build(deps): bump webpack (#5274)
  * build(deps): bump webpack (#5277)
  * Bump Go SDK to latest in our own internal tooling (#5280)
  * Bump golang.org/x/tools from 0.1.10 to 0.9.3 (#5279)
  * chore: Use expand PATH instead of string concatenation (#5271)
  * build(deps): bump remark-code-import from 1.1.1 to 1.2.0 in
    /website (#5269)
  * build(deps): bump github.com/charmbracelet/bubbles from 0.15.0
    to 0.16.1 (#5254)
  * build(deps): bump webpack (#5278)
  * build(deps): bump github.com/charmbracelet/bubbletea (#5250)
  * build(deps): bump webpack (#5276)
  * build(deps): bump webpack (#5273)
  * build(deps): bump github.com/magefile/mage in /internal/mage
    (#5262)
  * build(deps): bump golang.org/x/oauth2 from 0.7.0 to 0.8.0
    (#5253)
  * build(deps): bump webpack (#5173)
  * build(deps): bump react-social-login-buttons in /website
    (#5266)
  * build(deps): bump golang.org/x/crypto from 0.8.0 to 0.9.0
    (#5252)
  * build(deps): bump github.com/prometheus/procfs from 0.9.0 to
    0.10.1 (#5249)
  * docs: Added recipe creation info to style guide (#5230)
* Fri Jun  2 2023 kastl@b1-systems.de
- Update to version 0.6.1:
  * bump vt100 to v0.1.2 to fix panic (#5247)
  * Update retries to 10 minutes (#5246)
  * Import Elixir SDK as Experimental (#5201)
  * tui: avoid unnecessary byte/string conversion (#5237)
  * Interactive TUI: better failure handling (#5232)
  * add dagger login/logout commands (#5132)
  * dagger run: support redirecting stdout/stderr (#5231)
  * chore: update go.sum (#5238)
  * feat: update dagger/graphql to rely on Int64 Scalar (#5227)
  * Prevent concurrent/leaked mutation in a couple of spots (#5233)
  * simplify progrock socket location (#5234)
  * fix `dagger listen` TUI integration (#5219)
  * bump progrock for gRPC + resilient draining (#5228)
  * Retry connecting to buildkit for 3 minutes. (#5222)
  * engine: update buildkit to commit w/ more cache ref logs
    (#5223)
  * feat: follow graphQL spec in strings encoding (#5169)
  * Container.Export: mkdir destination parent dir (#5221)
  * refactor(shim): only initialize secret scrubbing logic when
    secrets are set (#5217)
  * tests: fix slowness by disabling unnecessary session nesting.
    (#5224)
  * mc: add auth token via env var to cacheservice (#5225)
  * add `-s` / `--silent` for disabling TUI (#5218)
  * docs: Updated quickstart (#5214)
  * Improve releasing during 0.6.0 (#5199)
  * engine: handle LogOutput being nil (#5215)
  * cache: return error if cacheservice scheme is not supported
    (#5211)
  * tui: Add fallback for runtime dir permission denied errors.
    (#5210)
  * docs: Fix tip content in quickstart test (#5206)
  * engine: enable full goroutine stack trace dump in trace logs.
    (#5204)
  * cache: Bump import timeout. (#5200)
  * Reduce size of extra content in error output truncation test
    (#5195)
* Fri May 26 2023 kastl@b1-systems.de
- Update to version 0.6.0:
  * docs: Updated dagger run command reference (#5180)
  * Move CODE_OF_CONDUCT to the root of the repository (#5153)
  * Scrub secret plaintext arg from progrock vertex. (#5186)
  * Add expand option when adding environment variables (#5160)
  * Add custom ExecError (#5184)
  * docs: Improved cache miss recipe for Python (#5189)
  * ci: Do not publish Rust SDK on push to `main` (#5187)
  * docs: Added cache invalidation recipe to cookbook (#5168)
  * docs: Added lima+nerdctl solution to alternatives guide (#5167)
  * Fix error handling in truncation notice (#5179)
  * ci: Fix publish-sdk-rust GitHub Actions workflow (#5178)
  * docs: Fix typo in quickstart-hello (#5170)
  * Increase truncation limit on error output (#5164)
  * Prepend truncated error output with notice (#5163)
  * chore: cleanup unused files and redundant Makefile commands
  * ci: add large machine for rust lint
  * ci: Add large machine to sdk/rust/test
  * ci: removed test provisioning as it is a missing feature, will
    require follow up
  * chore: add authors optional Cargo.toml field
  * chore: change rust sdk repo to dagger/dagger
  * chore: remove unused ci jobs
  * ci: with rest of workflows
  * ci: add publish step
  * ci: fix rust sdk stable image, now actual image
  * feat: remove dagger-core from crates to simplify release
    process
  * ci: add bump function for the engine dependency version
  * ci: add lint function for sdk:rust
  * ci: add generate function for sdk:rust
  * ci: add test setup for rust:sdk:test
  * feat: build and from keep previous configuration. (#5052)
  * use TUI for `dagger do`, `dagger query`, `dagger listen`
    (#5151)
  * Improve releasing during v0.5.3 (#5155)
  * Add experimental warning to the Rust SDK
  * Add CODEOWNERS for sdk/rust
  * 🚀 chore(README.md): check off introducing thiserror for better
    errors in plan for next release The plan for the next release
    has been updated to reflect that the
    [thiserror](https://docs.rs/thiserror/latest/thiserror/)
    library has been introduced to improve error handling.
  * Add thiserror instead of exposing eyre anonymous errors
  * 🚀 chore(Cargo.toml): add thiserror crate to dependencies The
    thiserror crate has been added to the dependencies in the
    Cargo.toml file. This crate is used to derive custom error
    types with automatic source location.
  * chore(README.md): mark dagger run compatibility and upstream
    update tasks as completed
  * refactor(dagger-codegen): remove unnecessary mutability from
    field variable in for loop
  * feat: dagger-run support
  * fix: remove _ from _type
  * feat: set cache config in proper place
  * feat: add inline export of variable
  * feat: expose runtime
  * chore: update ci
  * feat: update to dagger-5.1
  * chore: add new dagger-core-version
  * Release dagger-core v0.2.10
  * fix: delete other files/folder in downloads: #57
  * docs: add checklist for missing features
  * feat: with gen
  * feat: with 0.4.2
  * feat: fix codegen
  * fix(deps): update rust crate futures to 0.3.28
  * feat: add musl ci (#51)
  * feat: with multi platform ci (#46)
  * feat: extract client (#48)
  * feat: rename projects to point to github/kjuulh/dagger-sdk
  * feat: with loggers
  * fix: stable input fields and args
  * chore: fmt
  * fix: stable enum entries
  * refactor: add basic cargo make gen command
  * refactor: move dagger-rs and adopt workspace.deps
  * Release dagger-sdk v0.2.19
  * chore: fix release version
  * fix: serialization of enum args for graphql (#34)
  * feat: update readme
  * Release dagger-sdk v0.2.17
  * fix: make sure tests have a command to execute
  * fix: remove unused imports
  * refactor: remove export and instead use exitcode
  * refactor: move issues to actual tests and refactor
  * fix: add support for String as well
  * refactor: move issues to another folder
  * fix: add public tuple field and into func
  * replication(issue-30): initial issue
  * fix(deps): update rust crate futures to 0.3.27
  * docs: add basic contributing
  * docs: add architecture
  * fix: proper readme
  * Release dagger-core v0.2.8, dagger-sdk v0.2.16
  * chore: fix tasks
  * feat: with dagger-engine v.0.4.0
  * feat: bump version
  * docs(sdk): fix missing await in connect
  * feat: add tests to sdk
  * feat: set internal warnings as errors
  * feat: introduce tests again
  * Release dagger-core v0.2.7, dagger-sdk v0.2.15
  * fix: set deserialize on enums as well
  * feat: update to dagger-v0.3.13
  * Release dagger-sdk v0.2.14
  * chore(sdk): fix whitespace
  * Release dagger-codegen v0.2.8, dagger-sdk v0.2.13
  * chore(sdk): ran clippy
  * feat(sdk): with clone
  * Release dagger-core v0.2.6, dagger-codegen v0.2.7, dagger-sdk
    v0.2.12
  * chore(sdk): ran clippy
  * fix(core): cli session keep session alive
  * fix(ci): set path to local dagger sdk
  * Release dagger-core v0.2.5, dagger-sdk v0.2.12, dagger-codegen
    v0.2.7
  * fix(all): race condition in process
  * revert disable caching
  * disable cache
  * chore(ci): with dagger v0.2.11
  * Release dagger-core v0.2.4, dagger-codegen v0.2.6, dagger-sdk
    v0.2.11
  * fix(core): remove blocking
  * Release dagger-core v0.2.4, dagger-codegen v0.2.6, dagger-sdk
    v0.2.11
  * chore(sdk): ran clippy
  * fix(all): remove blocking
  * Release ci v0.1.0
  * docs(ci): add changelog
  * chore(ci): with actual await on connect
  * chore(ci): with dagger v0.2.10
  * Release dagger-rs v0.2.10
  * Release dagger-sdk v0.2.10
  * fix(docs): changelog
  * Adjusting changelogs prior to release of dagger-sdk v0.2.10
  * update changelog
  * Release dagger-rs v0.2.10
  * Release dagger-rs v0.2.10
  * Release dagger-rs v0.2.10
  * fix(ci): with older version of dagger-sdk
  * fix(core): Fix async panic on blocking #19
  * chore(ci): with async/await
  * Release dagger-sdk v0.2.8, dagger-codegen v0.2.5
  * Release dagger-sdk v0.2.7
  * docs: check async variant
  * feat(sdk,core): Use async runtime instead of blocking.
  * chore(ci): update ci to use dagger-sdk v0.2.6
  * Release dagger-sdk v0.2.6
  * docs: fix readme
  * Release dagger-sdk v0.2.5, dagger-codegen v0.2.4
  * fix: cargo clippy
  * fix: roadmap item api stabilization
  * Release dagger-sdk v0.2.4
  * Release dagger-sdk v0.2.3, dagger-codegen v0.2.3, dagger-rs
    v0.2.9
  * feat(core,sdk): remove unnecessary option returns
  * feat(ci): add gha caching
  * feat: clear release-cycle roadmap item
  * feat(ci): lint pr
  * feat(ci): ci with dagger v0.2.2
  * Release dagger-core v0.2.2, dagger-codegen v0.2.2, dagger-rs
    v0.2.8
  * with bin cache
  * fix(deps): update rust crate dagger-sdk to 0.2.1
  * add cache
  * fix(ci): fix github secret naming
  * run everywhere
  * fix(ci): with secret
  * feat(ci): with sccache
  * test change
  * Release dagger-sdk v0.2.1
  * add dagger-sdk changelog
  * Release dagger-rs v0.2.7, dagger-sdk v0.2.1
  * fix: with test changes
  * Release dagger-rs v0.2.6
  * fix: cleanup
  * Release dagger-rs v0.2.5
  * Release dagger-rs v0.2.4
  * fix: trying agian
  * Release dagger-rs v0.2.3
  * feat: some test
  * Release dagger-rs v0.2.2
  * with test commit
  * feature: trying smart-release
  * Release dagger-core v0.2.1, dagger-codegen v0.2.1, dagger-rs
    v0.2.1
  * add changelogs
  * Release dagger-core v0.2.1, dagger-codegen v0.2.1, dagger-rs
    v0.2.1
  * update changelog
  * Adjusting changelogs prior to release of dagger-core v0.2.1,
    dagger-codegen v0.2.1, dagger-rs v0.2.1
  * add color eyre
  * feature with workspace (#8)
  * add ci (#7)
  * add ci
  * v0.2.6
  * remove with commit
  * fix(deps): update all dependencies (#5)
  * fix: wip action
  * fix: wip
  * with personal github token
  * Revert "merge releases"
  * fix: add merge
  * merge releases
  * bump version
  * with github token
  * only allow main
  * fix: test creator of tags
  * add creator of tags
  * add create release
  * with changelog
  * remove toolchain
  * with actual versions
  * with publish
  * codegen also with repository
  * with repo
  * with repo
  * with readme and license
  * with wildcard version
  * cargo version 0.2.0
  * add version to main
  * bump version
  * document usage
  * fix all clippy
  * add with dockerfile
  * with caching
  * add more quickstart
  * build the application
  * add test-the-application
  * with println
  * feature/add impl (#6)
  * fmt tests
  * add tests
  * pull out args wip
  * add async roadmap item
  * context and querier done
  * unpack response
  * context roadmap item
  * tested full flow initially
  * move code to dagger-core
  * with selection impl default
  * fix warnings
  * add roadmap items
  * fix test
  * test marshaller
  * test marshaller
  * implement sort by name and type
  * fix optional types for real
  * fix description
  * with proper optional types
  * set proper option type
  * add querier roadmap item
  * add fields
  * add input_fields
  * with objects
  * remove hardcoded test
  * add documentation roadmap item
  * add architecture
  * clippy: fix
  * formatting
  * remove dummy string
  * Add querier
  * with status
  * with input objects
  * with enum
  * with codegen output
  * added scalars
  * with scalars
  * split out codegen parts
  * add dagger-sdk
  * add collection of types
  * with type filtering
  * with fixes
  * add todo for not dropping proc
  * can get schema
  * Add renovate.json
  * with session
  * with engine
  * Can download dagger
  * v0.1.1
  * with disclaimer
  * with out keeper
  * set readme and license
  * more allow dead_code
  * allow dead_code
  * without integration
  * Add base sdk
* Fri May 19 2023 kastl@b1-systems.de
- Update to version 0.5.3:
  * docs: withEnvVariables examples (#5139)
  * docs: pasted the output of tree that I got (#5047)
  * Add `Container.sync` field to force evaluation (#5071)
  * build(deps): bump github.com/cloudflare/circl from 1.1.0 to
    1.3.3 (#5130)
  * Recover app bootstrapping in Python entrypoints (#5152)
  * Create CODE_OF_CONDUCT.md (#5133)
  * Add support for forced compression in image publish+export
    (#5142)
  * core: upgrade buildkit dep to commit w/ trace log support.
    (#5143)
  * Project Commands (#5060)
  * Improve RELEASING during v0.5.2 (#5129)
  * Docs: Add caching support to Go multi-Arch examples (#5138)
  * Extend parallelization of integration tests (#5134)
* Thu May 11 2023 kastl@b1-systems.de
- Update to version 0.5.2:
  * Cache results for Container.Import and Container.Build (#5014)
  * raise an error for WithWorkdir + existing session (#5126)
  * fix Version handling (#5125)
  * docs: Made sidebar menu collapsible (#5120)
  * Implement chunked reader for File.Contents (#5123)
  * Introduce Progrock and inline progress UI (#5078)
  * docs: Removed CUE references (#5097)
  * Upgrade to buildkit commit with fix for cache ref leak. (#5122)
  * docs: quickstart, fix Go publish snippet (#5121)
  * test: add initial test for RegistryAuthProvider in auth package
    (#5119)
  * Grab bag of minor logging+performance improvements in cache
    (#5116)
  * Minor test coverage improvement for marshalling functions
    (#5115)
  * telemetry: update auth flow (#4987)
  * docs: Add new recipes to cookbook (#5040)
  * build(deps): bump golang.org/x/net (#5113)
  * build(deps): bump golang.org/x/sync from 0.1.0 to 0.2.0 (#5111)
  * Revert "Use strings.Builder for querybuilder marshal method
    (#5008)" (#5114)
  * build(deps): bump golang.org/x/term from 0.7.0 to 0.8.0 (#5108)
  * build(deps): bump github.com/google/go-github/v50 from 50.1.0
    to 50.2.0 (#5104)
  * build(deps): bump golang.org/x/sync in /internal/mage (#5100)
  * tooling: Reduce frequency of Dependabot PRs (#5099)
  * docs: Used stderr in get started guide snippets (#5094)
  * docs: Added multi-lang snippets for host fs guide (#4999)
  * docs: Fix quickstart Node.js tabs (#5089)
  * python: Broaden `Path` type in `Config` (#5090)
  * docs: Updated Node.js get started guide (#5030)
  * Use strings.Builder for querybuilder marshal method (#5008)
  * docs: Fixed error in quickstart caching embed (py) (#5085)
  * docs: Added guide on Docker alternatives (#5053)
  * docs: Added troubleshooting guide (#5046)
  * fix: Correct help output examples for dagger run (#5009)
  * telemetry: make run_id optional (#5066)
  * docs: Added lang snippets for multi-stage guide (#5028)
  * Truncate stdout/stderr from shim rather than session. (#5072)
  * docs: Updated embeds to use correct repo (#5059)
  * cache: Support extra headers for pre-signed URLs (#5068)
  * cache: Use URLs to sync layers and mounts. (#5050)
  * Add support for pushing engine logs to cloud (#5051)
  * add --pprof flag for serving net/http/pprof handlers (#5011)
  * Improve releasing during v0.5.1 (#5056)
* Sun Apr 30 2023 kastl@b1-systems.de
- Update to version 0.5.1:
  * core: Implicitly call `entrypoint` + `defaultArgs` when needed
    (#5039)
  * docs: Clarified Python get started steps (#5029)
  * docs: Fixed inconsistent Node.js tab labels (#5018)
  * engine: upgrade buildkit to fix for cache ref leak (#5031)
  * engine: Ensure that dnsmasq subprocess is killed (#5032)
  * Ensure engine exits 0 when it receives SIGTERM/SIGINT. (#5024)
  * dnsmasq: stability improvements + greater debuggability (#5015)
  * engine/cache: release refs after push (#5022)
  * strip sourcemap from Dockerfile builds (#5012)
  * Use strings.Builder for querybuilder build method (#5007)
  * TUI: support PgUp/PgDn/Home/End in log output (#4998)
  * docs: Updated CI guide (#4952)
  * keep 755 perms for cache with changed owner (#5006)
  * Add some more debug endpoints to the engine process. (#5003)
  * Use background context to release gateway containers. (#5005)
  * core: refactor away from fooIDPayload pattern (#4973)
  * Support configuring ownership (almost) everywhere (#4932)
  * docs: Updated FAQ (#4959)
  * fix(tui): added h and l as alt collapse/expand bindings (#4997)
  * fix out-of-order event delivery (#4996)
  * avoid using HTML chars in doc string (#4988)
  * docs: improve Copy Embedded Directories into a Container
    (#4974)
  * feat: pass secrets to Container.Build and Directory.Build
    (#4971)
  * ci: set proper octal notation file permissions (#4985)
  * fix flock usage for addnhosts (#4983)
  * Flush cache mounts on cache manager close. (#4980)
  * Bump graphql-tools-go for session start performance fix (#4977)
  * test: fix test for directory.dockerBuild (#4976)
  * ci: use mounted cache for go modules download (#4975)
  * Fix goroutine leak in cache import. (#4970)
  * docs: Added Dagger with PHP and Laravel guide (#4913)
  * First pass at dagger-in-dagger CI! (#4848)
  * docs: Added cookbook (#4938)
  * docs: use withDirectory (#4969)
  * Print engine name to it's own logs (#4964)
  * Sort out custom transport logic for CLI sessions to fix
    goroutine leak (#4960)
  * Add ability for clients to print which engine they are
    connected to. (#4909)
  * Add support for cache service. (#4923)
  * docs: Added note to secrets guide (#4956)
  * docs: Added note  in services guides (#4955)
  * collect `github.com/pr.branch` label (#4933)
  * docs: Merged CI guides (#4937)
  * build(deps): bump oss.terrastruct.com/d2 from 0.1.5 to 0.2.4
    (#4722)
  * tests: add additional test on chain operations (#4907)
  * Go: Implementation of (Container|Directory)With (#4898)
  * build(deps): bump github.com/docker/docker (#4891)
  * build(deps): bump golang.org/x/term from 0.5.0 to 0.7.0 (#4895)
  * build(deps): bump google.golang.org/protobuf from 1.29.0 to
    1.29.1 (#4899)
  * Improve releases instructions during v0.5.0 (#4908)
  * ci: bump dagger version in mage targets (#4931)
  * Container: add withExec(skipEntrypoint: Boolean) (#4919)
  * Set HTTP source filename to be URL. (#4927)
  * build(deps): bump sass from 1.59.3 to 1.61.0 in /website
    (#4917)
  * docs: Updated service containers guide reg. ports (#4897)
  * docs: Updated requirements for PHP/Rust (#4869)
  * docs: Added multi-language snippets to multibuild guide (#4875)
  * build(deps): bump google.golang.org/grpc from 1.52.3 to 1.54.0
    (#4815)
* Thu Apr 13 2023 kastl@b1-systems.de
- BuildRequire go1.20
- Update to version 0.5.0:
  * Set secret store in engine internal session. (#4903)
  * feat: append information to dagger session user_agent flags
    (#4892)
  * Improve instructions while releasing v0.4.1 (#4776)
  * feat: Allow labels to be specified on `dagger session`. Add
    default labels. (#4802)
  * `withExposedPort` also exposes port in OCI image config (#4900)
  * Add more debug log lines to engine start. (#4901)
  * Container: add `import` API (#4876)
  * Interactive logs via `dagger run` (#4522)
  * docs: Highlight for better readability on code blocks (#4882)
  * fix: use the right syntax for deprecated comments with
    supersedure (#4885)
  * Docs: tweak quickstart examples (#4880)
  * Upgrade go releaser image to pick up go 1.20. (#4887)
  * Safeguard pdeathsig usage in shim w/ os thread lock. (#4886)
  * Update to latest buildkit commit. (#4879)
  * docs: Updated style guide for embeds (#4874)
  * docs: Added guide for local exports (#4814)
  * docs: (fix) remove 'r' from .with_registry_auth statement
    (#4873)
  * docs: fix external link icons (#4788)
  * docs: updated requirements for AWS CDK guide (#4813)
  * docs: Added database example to services guide (#4867)
  * docs: Added guide for secrets (#4822)
  * docs: Added tsc instruction to Node get started (#4868)
  * feat!: deprecate HostVariable.secret in favor of setSecret
    (#4862)
  * docs: Update service containers guide (#4851)
  * feat: scrub secrets containing whitespace (#4772)
  * collect github.com/pr.head label (#4849)
  * docs: remove guides.json from git index (#4853)
  * docs: Added multi-lang snippets for GitHub guide (#4811)
  * Use a more flexible way to collect data from GitHub events
    (#4847)
  * docs: add multi-language snippets to "replace dockerfile" guide
    (#4778)
  * test: bump dagger version for mage tasks (#4836)
  * Add flag for configuring max parallel execs in engine. (#4834)
  * engine: Use MergeOp to optimize size of CombinedResult. (#4824)
* Fri Mar 24 2023 kastl@b1-systems.de
- Update to version 0.4.2:
  * Upgrade to buildkit w/ performance fix.  (#4817)
  * fix: withRegistryAuth uses secret.Store for getting plaintext
    (#4809)
  * Configurable network name and address range (#4711)
  * Docs: fix diagram (#4797)
  * docs: remove default tags pages (#4794)
  * docs: widen guides codeblocks (#4784)
  * update go replace dockerfile guide with default cmd (#4781)
  * Add playground version check instructions (#4792)
  * feat: improve Go SDK to fetch list of objects (#4683)
  * telemetry: rotate cloud token (#4786)
  * build(deps): bump spectaql from 2.0.4 to 2.0.5 in /website
    (#4725)
  * build(deps): bump @sideway/formula from 3.0.0 to 3.0.1 in
    /website (#4751)
  * build(deps): bump webpack from 5.74.0 to 5.76.1 in /website
    (#4765)
  * build(deps): bump sass from 1.58.0 to 1.59.3 in /website
    (#4769)
  * docs: Quickstart improvements (#4532)
  * wire up v0.4.1 engine journal delivery (#4779)
  * docs: fix guides rendering (#4780)
  * update demo CTA at top (#4777)
  * sdk: Bump engine dependency to v0.4.1 (#4775)
  * docs: adds guide for the AWS CDK (#4734)
* Fri Mar 17 2023 kastl@b1-systems.de
- Update to version 0.4.1:
  * add github.com/repo.full_name, github.com/repo.url (#4767)
  * Telemetry ingestion (#4637)
  * feat: add dynamic secret API (#4667)
  * run services tests in parallel (#4764)
  * Collect more git labels, silence noisy log (#4763)
  * Prevent GC of content pending export. (#4758)
  * Initial support for cache mount import/export. (#4671)
  * docs: add origin as embed domain (#4753)
  * docs: proxy embed to avoid third party errors (#4752)
  * Improve releasing instructions post v0.4.0 (#4741)
  * Use zstd compression for s3 cached layers. (#4746)
  * docs: Updated minimum Go version for Go SDK (#4743)
  * docs: Updated title and content to reflect the final feature
    name (#4744)
  * docs: Improved services guide (#4740)
  * docs: Added services guide (#4712)
  * Fix loading GitHub labels for push events (#4691)
  * docs: add tag search to guide index (#4686)
* Wed Mar  8 2023 kastl@b1-systems.de
- Update to version 0.4.0:
  * docs: fix create embed script for node/ts (#4730)
  * docs: untrack guides.json (#4732)
  * Raise error when using container has not been executed (#4716)
  * fix grep -v in entrypoint causing early exit (#4733)
  * docs: Fixed broken link to API concepts page (#4728)
  * docs: Added multi-language snippets and text for Gitlab +
    Google Cloud guide (#4688)
  * Use singleton cache manager for experimental s3 cache pooling.
    (#4715)
  * Support privileged executions. (#4677)
  * fix mutating vertex with LogOutput set (#4695)
  * docs: Converted snippets to embeds for API Concepts doc (#4687)
  * Disable networking before spinning up engine in remotecache
    test. (#4697)
  * Disable CNI for remotecache tests to address flake. (#4696)
  * add GitHub workflow/job name in labels (#4690)
  * docs: Stderr() used in code instead of ExitCode() (#4534)
  * add labels for github metadata from actions run (#4672)
  * invert services feature flag (#4682)
  * Note that tests should be run with ./hack/dev (#4681)
  * Apply Dagger engine config defaults at runtime, configure MTU
    that matches default interface (#4666)
  * fix: check for file name length (#4654)
  * Pipeline Labels (#4615)
  * Flush engine logs on Go SDK client close (#4656)
  * better resolv.conf/dnsmasq setup (#4658)
  * docs: Added guide metadata, updated links and paths (#4598)
  * docs: Fixed quickstart code snippets (#4655)
  * Make services feature opt-in (#4657)
  * fix: contents was not assigned in go_sdk tests (#4650)
  * bump golangci-lint, fix lints (#4649)
  * docs: add new layout to quickstart (#4537)
* Sat Feb 25 2023 kastl@b1-systems.de
- Update to version 0.3.13:
  * docs: fixes docs code examples in the quickstart (#4632)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.31.6 to
    1.34.0 (#4639)
  * Additive caching support for S3 backend (#4577)
  * chore: Add graphql example for pipeline (#4467)
  * docs: point to new version of GHA (#4595)
  * docs: Added instructions for playground embeds (#4609)
  * feat: scrub secrets (#4518)
  * fix python linter (#4638)
  * Services, a.k.a. container-to-container networking (#4505)
  * Update buildkit to commit w/ cache exporter fix + nil panic
    fix (#4630)
  * Get sha of the image after Container.From (#4600)
  * Refactor NodeJS codegen (#4360)
  * docs: improve GraphQL with example and better format (#4367)
  * fix Directory.WithTimestamps with subdir (#4606)
  * Create a test for nested arguments (#4599)
  * Fix the buildargs regex (#4597)
  * build(deps): bump typedoc from 0.23.24 to 0.23.25 in /website
    (#4593)
  * Pull engine image from registry.dagger.io (#4517)
  * docs: Added GitLab + Google Cloud tutorial (#4552)
  * chore(python): Explicitly add dependencies used directly in
    codebase (#4578)
  * Create `with()` method to chain objects (#4332)
  * Disable logrus output only in CLI main. (#4572)
  * chore(deps): Update python linter (#4565)
  * fix: Enhance synchronous error message call. (#4485)
  * Use comma instead of semicolon for cache config separator.
    (#4563)
  * Remove import dependency of CLI on containerd packages.
    (#4562)
  * fix: remove workdir & configPath default values. (#4465)
  * ci: simplify step to run workflows for bump PR (#4560)
  * Download runc binary instead of building it.  (#4559)
  * Initial support for remote cache config. (#4543)
  * sdk: Bump engine dependency to v0.3.12 (#4554)
  * Update RELEASING.md instructions on testing (#4461)
* Fri Feb 10 2023 kastl@b1-systems.de
- Update to version 0.3.12:
  * build(deps-dev): bump pytest-subprocess in /sdk/python (#4482)
  * feat: implements registry auth on container (#4502)
  * feat: implement cache sharing mode + add GraphQL enum type (#4437)
  * Fix TestDirectoryWithTimestamps for non-ext4 filesystems (#4548)
  * build(deps): bump typescript from 4.9.4 to 4.9.5 in /website (#4495)
  * build(deps): bump sass from 1.57.1 to 1.58.0 in /website (#4510)
  * build(deps): bump @docusaurus/preset-classic in /website (#4536)
  * docs: Fix Rust,PHP syntax highlight and API response in GraphQL docs (#4533)
  * build(deps): bump @docusaurus/theme-mermaid in /website (#4530)
  * build(deps): bump @docusaurus/core from 2.3.0 to 2.3.1 in /website (#4529)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4494)
  * Fix cache key examples in Go and Python SDKs (#4446)
  * chore: fallback to existing engine with docker (#4489)
  * This commit updates the sed command line in the (#4525)
  * docs: Added platform clarification in Google Cloud + GitHub guide (#4526)
  * docs: Updated quickstart example repository URL (#4527)
  * add entrypoint to engine image (#4521)
  * ci: Pass engine test job if otel-collector fails (#4512)
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4496)
  * Generate strictly typed scalars to improve type safety (#4503)
  * ci: Improve how we handle cached vertices (#4498)
  * Adds minor fixes to quickstart (#4506)
  * Add quickstart fixes (#4500)
  * build(deps-dev): bump typescript from 4.9.4 to 4.9.5 in /sdk/nodejs (#4492)
  * This commit upgrades Docusaurus to 2.3.0 and corrects (#4497)
  * docs: Added quickstart guide (#4391)
  * fix: Merge container from env vars with existing env vars (#4455)
  * refactor: group common funcs into upper interface (#4415)
  * build(deps-dev): bump eslint from 8.32.0 to 8.33.0 in /sdk/nodejs (#4481)
  * website: remove amplitude (#4433)
  * ci: Upload journal.log & comment.md as artifacts (#4487)
  * engine: fix workdir verification on Windows (#4486)
  * Fix session error handling (#4421)
  * Remove PR comments for engine tests (#4478)
  * build(deps): bump @docusaurus/theme-mermaid in /website (#4475)
  * website: fix code tags css in dark mode (#4468)
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4430)
  * ci: Collect traces & logs from pipeline runs and publish to Loki & Tempo  (#4340)
  * Fixed Node.js multibuild example (#4452)
  * Fix container use in nodejs get started guide. (#4462)
* Fri Jan 27 2023 kastl@b1-systems.de
- Update to version 0.3.10:
  * python: Codegen Enum types (#4448)
  * deps(python): Update ruff (#4444)
  * build(deps): bump ua-parser-js from 0.7.31 to 0.7.33 in /website (#4443)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4431)
  * build(deps): bump spectaql from 2.0.3 to 2.0.4 in /website (#4416)
  * build(deps): bump typedoc from 0.23.23 to 0.23.24 in /website (#4345)
  * chore(python): Adopt ruff (#4399)
  * Fix engine state path in operator manual. (#4423)
  * build(deps-dev): bump eslint from 8.31.0 to 8.32.0 in /sdk/nodejs (#4382)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4395)
  * chore: bump version of actions/add-to-project (#4427)
  * Implement label API (#4387)
  * bump buildkit to v0.11.1 (#4402)
  * [GraphQL Reference] add ids and anchor tags to each field (#4410)
  * build(deps-dev): bump pytest from 7.2.0 to 7.2.1 in /sdk/python (#4408)
  * Bugfix: CLI Download for Node.js SDK on Windows (#4390)
  * build(deps): bump axios from 1.2.2 to 1.2.3 in /sdk/nodejs (#4405)
  * build(deps-dev): bump poethepoet from 0.17.1 to 0.18.1 in /sdk/python (#4406)
  * Add live demo link (#4397)
  * experimental graph tool (#4365)
  * build(deps): bump beartype from 0.11.0 to 0.12.0 in /sdk/python (#4394)
  * change posthog analytics URL to minimize ad-blockers (#4396)
  * Pipeline fixes for RootFS and Git (#4392)
  * Add Exclude Sub-Directory tests (#3802)
  * ci: Disable flaky TestPipeline test (#4376)
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4388)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4385)
  * build(deps-dev): bump prettier from 2.8.2 to 2.8.3 in /sdk/nodejs (#4383)
  * Enhance docs typo readability (#4351)
  * build(deps-dev): bump @types/node in /sdk/nodejs (#4263)
  * build(deps-dev): bump prettier from 2.8.1 to 2.8.2 in /sdk/nodejs (#4342)
  * build(deps): bump docusaurus-plugin-sass from 0.2.2 to 0.2.3 in /website (#4343)
  * docs: Update the Node.js get started guide (#4377)
  * ci: Test provisioning for tagged artefacts which we publish (#4350)
  * docs: Added info on docs release process (#4337)
  * chore: Rename WithDevEngine to AdvertiseDevEngine (#4372)
  * chore: Rename test-dagger-engine to dagger-engine.dev (#4371)
  * fix(codegen/go): pass the GQL client to the returned client (#4369)
  * Group API (#4248)
  * feat: implement target to dockerfile build (#4362)
  * Journal file support (#4300)
  * fixes issue parsing DAGGER_SESSION_PORT and DAGGER_SESSION_TOKEN (#4359)
  * NodeJS: use ID only when it makes sense (#4313)
  * Document more runner conn types. (#4352)
  * Only runs test+lint on push to main branch. (#4349)
  * build(deps): bump golang.org/x/term from 0.3.0 to 0.4.0 (#4308)
  * Fix formatting of generated python cli version file. (#4348)
* Tue Jan 10 2023 kastl@b1-systems.de
- Update to version 0.3.9:
  * Fix linktime override of Version var. (#4346)
  * sdk: Bump engine dependency to v0.3.8 (#4338)
* Tue Jan 10 2023 kastl@b1-systems.de
- Update to version 0.3.8:
  * Add docs for custom provisioning and the session interface (#4232)
  * deps(python): Package updates (#4334)
  * sdk: python: Improve runtime type checking error message (#4333)
  * build(deps-dev): bump eslint from 8.30.0 to 8.31.0 in /sdk/nodejs (#4276)
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4314)
  * add link to examples repo in readme (#4326)
  * feat: improve error message on stopped dagger engine (#4284)
  * docs: add linting support for node snippets (#4328)
  * docs: improve GraphQL schema doc (#4240)
  * ci: avoid running publish workflows in forks (#4330)
  * docs: Add replace dockerfile with Go guide (#4173)
  * chore(python): Update default python version (#4298)
  * docs(python): Hide internal member from reference (#4295)
  * build(deps): bump golang.org/x/mod from 0.6.0 to 0.7.0 (#4318)
  * Support the rest of the default buildkitd conns. (#4288)
  * Change buildkit config+state to be dagger specific. (#4287)
  * build(deps): bump github.com/docker/cli (#4306)
  * build(deps): bump golang.org/x/sys from 0.3.0 to 0.4.0 (#4302)
  * feat(codegen/nodejs): improve Socket SDK object reusability (#4315)
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4262)
  * fix: session usage and double error prints (#4303)
  * Add zipfile cli download support for windows. (#4286)
  * Upgrade to buildkit v0.11-rc3. (#4296)
  * improve connect doc reference (#4250)
  * update local development section in the README (#4297)
  * fix(codegen/nodejs): generate the required method param documentation correctly (#4134)
  * Switch session url to port (#4285)
  * sdk: python: Use platform dependent cache dirs (#4281)
  * chore(python): Update Poetry in CI (#4292)
  * Python: Update locked packages (#4280)
  * setup nested session in the shim instead of the executor (#4260)
  * Added typesafe error names to nodesdk errors (#4283)
  * docs: explain how use local NodeSDK library. (#4265)
  * build(deps-dev): bump eslint-config-prettier in /sdk/nodejs (#4277)
  * website: Improve nodejs sdk docs readability (#4275)
  * style: improve NodeSDK utils code (#4274)
  * fix: NodeSDK correctly solves subqueries (#4266)
  * style: enhance NodeSDK coding style (#4269)
  * build(deps): bump axios from 1.2.1 to 1.2.2 in /sdk/nodejs (#4268)
  * build(deps): bump json5 from 2.2.1 to 2.2.2 in /website (#4273)
  * build(deps): bump certifi from 2022.9.24 to 2022.12.7 in /sdk/python (#4148)
  * sdk: nodejs: rename queryBuilder func (#4249)
  * sdk: python: Don’t timeout by default (#4175)
  * sdk: python: Refactor provisioning (#4255)
  * Make archive names consistent with previous naming scheme. (#4261)
  * fix(codegen/nodejs): make input type field generation ordered/stable (#4259)
  * fix(sdk/nodejs): use OS user cache path with "env-paths" (#4256)
  * docs: update private git docs (#4251)
  * Add build args to Dockerfile build (#4207)
  * Add file/folder permissions to Directory and Container APIs (#4157)
  * build(deps): bump attrs from 22.1.0 to 22.2.0 in /sdk/python (#4238)
  * docs: Use /var/run/docker.sock base64 (#4253)
  * build(deps-dev): bump mocha from 10.1.0 to 10.2.0 in /sdk/nodejs (#4166)
  * build(deps): bump graphql-request from 5.0.0 to 5.1.0 in /sdk/nodejs (#4228)
  * feat: NodeSDK generate input from GQL schema. (#4247)
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4167)
  * build(deps): bump typedoc from 0.23.21 to 0.23.23 in /website (#4223)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4229)
  * build(deps-dev): bump eslint from 8.29.0 to 8.30.0 in /sdk/nodejs (#4230)
  * build(deps): bump sass from 1.57.0 to 1.57.1 in /website (#4231)
  * Added types to error names and error codes (#4227)
  * build(deps-dev): bump typescript from 4.9.3 to 4.9.4 in /sdk/nodejs (#4165)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4169)
  * build(deps-dev): bump @types/node in /sdk/nodejs (#4218)
  * build(deps): bump spectaql from 2.0.2 to 2.0.3 in /website (#4224)
  * build(deps): bump sass from 1.56.2 to 1.57.0 in /website (#4225)
  * nodesdk: Split EngineSessionPortParseError into different errors (#4156)
  * cli: expose x-dagger-engine version with dagger listen (#4221)
  * ci: Add cli publish from main and tests against it. (#4208)
  * docs: add reference to custom api clients from cli overview (#4202)
  * cli: print complete GraphQL URL to stdout when listening (#4204)
  * Update SDK form (#4203)
  * Update SDKs to pull CLI from S3 URL. (#4194)
  * sdk: python: Fix inconsistencies in passing IDs to fields (#4195)
  * add toplevel socket query example (#4187)
  * sdk: python: Check input types at runtime (#4034)
  * update community call CTA (#4188)
  * chore: temporarly disable provision test (#4185)
  * chore: use index.mjs for file name (#4181)
  * ./hack/dev: export dagger binary for host platform (#4183)
  * Node.js GitHub + Google Cloud guide: remove awaited + fix the console.log (#4164)
  * CI examples (#4162)
  * Include output of failed exec in error message. (#4161)
  * cli: add disable-host-read-write flag to dagger listen (#4171)
  * build(deps): bump sass from 1.56.0 to 1.56.2 in /website (#4154)
  * build(deps): bump decode-uri-component from 0.2.0 to 0.2.2 in /website (#4077)
  * build(deps-dev): bump @types/node from 16.18.4 to 16.18.6 in /sdk/nodejs (#4114)
  * build(deps-dev): bump prettier from 2.8.0 to 2.8.1 in /sdk/nodejs (#4124)
  * build(deps): bump axios from 1.2.0 to 1.2.1 in /sdk/nodejs (#4115)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4139)
  * build(deps): bump typescript from 4.9.3 to 4.9.4 in /website (#4141)
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4140)
  * build(deps): bump amplitude-js from 8.21.2 to 8.21.3 in /website (#4153)
  * build(deps): bump spectaql from 1.5.8 to 2.0.2 in /website (#4155)
  * docs: Added GitHub + Google Cloud guide (#4135)
  * Use 127.0.0.1 instead of localhost for sessions. (#4159)
  * Replace engine-session binary w/ cli session cmd. (#4145)
  * Update client-gen to use engine.Start directly. (#4143)
  * update SDK request form URL (#4126)
  * chore: Link contributing doc partial to CONTRIBUTING.md (#4127)
  * CLI: use engine.Start directly  (#4119)
  * connect test helper prints logs
  * add File { withTimestamps }
  * add Directory.WithTimestamps
  * docs: remove YALM use case and add CUE warning (#4117)
  * Update container optional arguments (#4122)
  * website: remove what seems to be an unused package (#3475)
  * docs: Add first draft of style guide (#4004)
  * docs: add 0.2 older version warning page (#4116)
  * docs: update Node.js SDK optionals arguments (#4121)
  * sdk: nodejs: remove unused typedoc package (#4120)
  * docs: Add Go example for host fs guide. (#4110)
  * NodeJS SDK required + optional types (#4005)
  * doc(sdk/nodejs): export CallbackFct from connect.ts (#4091)
  * docs(python): Fix reference docs
  * build(deps-dev): bump @typescript-eslint/eslint-plugin in /sdk/nodejs (#4098)
  * Node.js SDK : Error handling (#3947)
  * docs: Fix GitLab CI configuration (#4108)
  * build(deps): bump typedoc-plugin-markdown in /website (#4101)
  * build(deps-dev): bump @typescript-eslint/parser in /sdk/nodejs (#4102)
  * build(deps): bump docusaurus-plugin-typedoc in /website (#4103)
  * docs: update go multistage guide to 0.4.2 (#4082)
  * build(deps-dev): bump typedoc-plugin-markdown in /sdk/nodejs (#4099)
  * build(deps-dev): bump eslint from 8.28.0 to 8.29.0 in /sdk/nodejs (#4100)
  * chore: Remove old examples dir (#4096)
  * chore: Improve RELEASING.md based on today's interactions (#4066)
  * Use one stable go sdk version to execute CI steps. (#4087)
  * sdk: nodejs: Always return a immutable object (#4081)
  * build(deps-dev): bump @types/node from 16.18.3 to 16.18.4 in /sdk/nodejs (#4068)
  * Add API to Playground title (#4074)
  * docs: add dagger do warning message (#4071)
  * ci: re-enable Go SDK mirroring on `main`
  * ci: nodejs bump: fix lint error (#4072)
  * sdk: Bump engine dependency to v0.3.7 (#4070)
  * DisableHostRW disables host socket access (#4067)
* Thu Dec  1 2022 kastl@b1-systems.de
- Update to version 0.3.7:
  * container: Support WithDirectory, WithFile & WithNewFile (#3827)
  * Add warning about releasing engine before SDKs.
  * docs: add link to docs in api reference logo (#4056)
  * docs: Adds security note for custom session (#4057)
  * docs: Add releasing instructions for Node.js SDK changelog (#3972)
  * docs: Add tech review badge to API page (#4062)
  * docs: update docs with DAGGER_SESSION_TOKEN. (#4052)
  * add test for Directory { dockerBuild }
  * feat: api: directory { dockerBuild }
  * docs: Add API/CLI links to sidebar (#4044)
  * docs: fix API Playground button style (#4043)
  * Container.WithUnixSocket replaces same path
  * add Container { withoutUnixSocket }
  * panic on unknown errors in tests
  * remove unnecessary python test fixture change
  * add test for git + SSH auth sock
  * remove auto SSH auth socket forwarding
  * add sshAuthSocket param to git.tree
  * support mounting host Unix sockets into containers
* Thu Dec  1 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.18
* Thu Dec  1 2022 kastl@b1-systems.de
- Update to version 0.3.6:
  Changelog (without SDK entries)
  * docs: Fixed some page slugs (#4042)
  * docs: add generated graphql api reference (#3745)
  * docs: Add API and CLI documentation (#3917)
  * Fix typo in dagger run help. (#4039)
  * Use HTTP basic auth for dagger session token. (#4030)
  * ci: Do not publish non semver CLI (#4028)
  * fix dagger run alias (#4027)
  * ci: Publish CLI & Engine at the same time (#4012)
  * make dagger run use a random path for DAGGER_SESSION_URL (#4026)
  * ci: Test Engine provisioning on MacOS (#3774)
  * rename exec to run (#4019)
  * fix: don't trim all whitespace (#3992)
  * chore(python): Refactor connectors
  * Check for already used error in nerdctl format too.
  * docs: Fix error in path of docs deprecation note (#3988)
  * ci: add CLI publishing to engine pipeline (#3980)
  * build(deps): bump alpine from 3.16 to 3.17 (#3981)
  * ci: Always run test & lint workflows (#3953)
  * chore: Add community call (#3924)
  * chore(python): Trivial formatting cleaning
  * docs: go: remove go mod replace as no longer needed
* Thu Dec  1 2022 kastl@b1-systems.de
- Update to version 0.3.5:
  Changelog (without SDK entries)
  * ci: publish: fix bump PR creation
  * ci: publish engine by tag rather than commit
  * Continue using engine image ref digests for now.
  * Don't log removal already in progress error.
  * ci: trigger engine push (#3955)
  * Don't include credential helpers on macos.
  * ci: fix publish engine flow (#3951)
  * Python: Add tests for improved Provisioning Error Messages (#3880)
  * Include linux engine-session bins in local dev engine.
  * docs(python): Fix usage of ids
  * Automatically mount dagger-engine-session from image.
  * build(deps): bump github.com/netlify/open-api/v2 from 2.12.1 to 2.12.2
  * Fix redirect of stdio to non root mount.
  * Revert "Fully hide shim from container process."
  * docs(python): Lint doc snippets
  * docs: Add deprecation note, update /install page (#3915)
  * api: Deprecate Exec in favor of WithExec. Make args mandatory.
  * ci: cli distribution (#3901)
  * api: Return the contents directly in Container Stdout/Stderr
  * Fully hide shim from container process.
  * Execute runc as child process instead of exec.
  * api: directory.withNewFile: make contents option mandatory
  * build(deps): Bump google.golang.org/grpc from 1.49.0 to 1.51.0
  * Default nested dagger to bin://
  * Include host docker dir in dagger-in-dagger tests.
  * Use different image refs for different test cases.
  * Add bin connector to python.
  * Add bin connector to nodejs.
  * Support full isolated sessions w/ dagger-in-dagger.
  * Passthrough runc commands that don't have a bundledir.
  * Change shim to be an oci-runtime wrapper.
  * docs: update workdir -> directory
  * api: Deprecate host.workdir
  * build(deps): Bump typescript from 4.8.4 to 4.9.3 in /website
  * python: add deprecated admonitions
  * api: replace fs by rootfs
  * codegen: support @deprecated directive
  * build(deps): Bump loader-utils from 2.0.3 to 2.0.4 in /website (#3859)
  * docs: lint NodeJS snippets (#3867)
  * Remove cloak from a comment
  * docs: Tabs for JavaScript & TypeScript (#3888)
  * First take at Dagger CLI (#3748)
  * Node Feedback (#3872)
  * build(deps): bump github.com/containerd/containerd from 1.6.9 to 1.6.10 (#3817)
  * remove trailing spaces
  * build(deps): bump github.com/moby/buildkit from 0.10.5 to 0.10.6 (#3795)
  * NodeJS Provisioning Follow ups  (#3861)
  * docs(python): port private registry docs to python (#3760)
  * docs: Add FAQ entry for container registry auth (#3876)
  * remove unused types.ts file (#3868)
  * Remove unessary semicolons
  * Remove temp files on error.
  * Fail when session binary copy command fails.
  * Add http engineconn to nodejs.
  * chore: Ingore .env & .envrc files
  * chore: Rename NodeJS mage namespace
  * Fix go lint
  * fix(codegen/nodejs): use the direct graphql-request lib
  * test(codegen/nodejs): remove full api output test
  * fix(codegen/nodejs): use updates from the provisioning part
  * refactor(codegen/nodejs): remove unused templates+tests
  * refactor(codegen/nodejs): move return next to return_solve
  * refactor(codegen/nodejs): change custom scalar from `any` to `string`
  * refactor(codegen/nodejs): remove call_arg
  * feat(codegen/nodejs): expand args in the function param list
  * refactor(codegen/nodejs): make template functions and funcmap private
  * fix(codegen/nodejs): remove FIXME
  * ci(codegen/nodejs): make linter happy
  * test(codegen/nodejs): add golden update capacity for full API file
  * fix(codegen/nodejs): fix imports and file destination in the codegen
  * feat(codegen/nodejs): add autogenerated warning on the top of node generated API file
  * chore(codegen/nodejs): cleanup unused code/tests
  * fix(cli): remove default language generation
  * ci(codegen/nodejs): make linter happy
  * feat(cli): enable nodejs codegen
  * refactor(codegen): refactor codegen to enable Go and NodeJS generation
  * refactore(codegen/nodejs): rename full test into api test
  * refactor(codegen): move generator in codegen/generator
  * refactor(codegen/nodejs): rename dir from ts to nodejs
  * refactor(codegen/nodejs): cleanup template functions
  * refactor(codegen/nodejs): move filter of graphql __Xxx types in objects template
  * refactor(codegen/nodejs): move more logic in leaf templates
  * build(codegen/nodejs): bump strcase
  * refactor(codegen/nodejs): update templates
  * test(codegen/nodejs): document template
  * test(codegen/nodejs): add full codegen file test
  * test(codegen/nodejs): fix test fixtures
  * test(codegen/nodejs): fix test fixtures for optionals
  * feat(codegen/nodejs): make args optional if possible
  * fix(codegen/nodejs): use correct typescript way of declaring a custom type
  * fix(codegen/nodejs): remove duplicate custom scalars
  * fix(codegen/nodejs): suffix [] at the end of the type
  * fix(codegen/nodejs): also prefix args by Client instead of Query
  * fix(codegen/nodejs): use typescript boolean type
  * fix(codegen/nodejs): filter out "__Xxx" types
  * refactor(codegen/nodejs): update code block for sync code
  * fix(codegen/nodejs): improve scalar types generation
  * refactor(codegen/nodejs): indent object template
  * fix(codegen/nodejs): rename Query into Client + export type
  * fix(codegen/nodejs): remove Scalars['xxxtypexxx']
  * feat(codegen/nodejs): use correct schema json
  * feat(codegen/nodejs): only include type if it is not nil
  * test(codegen/nodejs): integrate type with objects
  * feat(codegen/nodejs): add args type generation
  * fix(codegen/nodejs): add missing templates
  * feat(codegen/nodejs): handle optional args type
  * refactor(codegen/nodejs): integrate with a more complete test
  * feat(codegen/nodejs): add scalar type field body
  * feat(codegen/nodejs): add field body for non scalar types
  * fix(codegen/nodejs): add solveable return template
  * feat(codegen/nodejs): return the async type for scalar types
  * fix(codegen/nodejs): include *.ts.tmpl files
  * fix(codegen/nodejs): make linter happy
  * feat(codegen/nodejs): handle sync return type (without solving)
  * fix(codegen/nodejs): don't generate empty comments blocks
  * test(codegen/nodejs): use lang flag
  * test(codegen/nodejs): use more realistic schema data
  * feat(codegen/nodejs): add input args types template
  * feat(codegen/nodejs): add pascal and camel case formatting template funcs
  * refactor(codegen): split IntrospectAndGenerate into Introspect and Generate
  * feat(codegen/nodejs): pass args as `args: { xxx }`
  * feat(codegen/nodejs): add lang flag for client-gen
  * refactor(codegen/nodejs): reformat test data
  * fix(codegen/nodejs): fix the arg template to use a *TypeRef
  * refactor(codegen/nodejs): harmonize templates whitespace deletion
  * ci(codegen/nodejs): make linter happy
  * ci(codegen/nodejs): simplify Solve template func
  * feat(codegen/nodejs): first version of object generated
  * fix(codegen/nodejs): fix comment linting
  * refactor(codegen/nodejs): remove unused comment template func
  * test(codegen/nodejs): add comments to object template
  * test(codegen/nodejs): add template deps in templateHelper
  * test(codegen/nodejs): add multi line comments
  * feat(codegen/nodejs): add simple comments
  * refactor(codegen/nodejs): move subtract into the templates package
  * refactor(codegen/nodejs): improve args test
  * refactor(codegen/nodejs): split args functions into template
  * refactor: extract Generator interface and specialize for Go
  * fix(codegen): imports after move
  * refactor: move go generator in its own directory
  * Use unix timestamp in nanosecond to generate a random id used when creating a temporary bin file path
  * use kill process from execa which is using SIGTERM then SIGKILL
  * feat: finish engine callback connection
  * fix: broken api test
  * rebase main branch
  * Make docker-image default connect implementation.
  * Spawn engine session subprocess and read port.
  * Set nodejs provision output directly to temporary binary.
  * Prevented the attempted read of an None or unreadable stderr.
  * Improved error message when dagger engine is cached but docker is not running.
  * Improved error messages when docker is not installed/running.
  * Added DaggerException.
  * chore(pyhon): Add dependabot
  * Fix use of xdg dir in python provision test.
  * Use pytest fixture and anyio
  * Add docker image provisioner test.
  * Fix dockerfile path join in windows
  * ci: Only publish engine when specific paths change
  * fix(race): TestConnectOption racing on buffer's write (#3792)
  * ci: Rename Node to NodeJS
  * ci: Preserve oldest supported Node.JS version when running tests
  * ci: Fix readthedocs os value
  * ci: basic NodeJS support
  * ci: limit usage of large runners
  * Include kernel logs in gha output.
  * Add `WithAllowWildcard` to `(dir *Directory) Without()` (#3735)
  * Deal with Scratch correctly (#3759)
  * ci: remove mage from engine:publish
  * docs: remove --pre from pip install
  * docs: indicate that config is optional
  * ci: Switch to Makefile
  * update multistage guide with suggestions
  * update multistage build best practice
  * add multistage build guide to guides list
  * start multistage build guide
* Thu Dec  1 2022 kastl@b1-systems.de
- Update to version 0.3.4:
  Changelog (without SDK entries)
  * docs: Minor addition to guide
  * docs: Make first example give immediate feedback
  * Ensure shim can build when exec'ing on scratch.
  * Include .exe suffix in engine-sesion bin on windows.
  * Add windows engine-session binaries to engine image.
  * Fix obscure race condition that can result in ETXTBSY.
  * Add test for docker image provision.
  * Don't unlink docker-container tmpbin after process starts.
  * Add engine:publish workflow to GHA.
  * Add engine release instructions.
  * Fix lint errors.
  * Centralize more provisioning logic to be in helper.
  * docs(cue): fix command to install specific version (#3708)
  * build(deps): bump sass from 1.55.0 to 1.56.0 in /website
  * Disable logrus to prevent library spam.
  * Run engine -race tests w/ mage
  * Print dagger engine logs at end of CI.
  * Make it easier to debug empty docker-container:// engineconn.
  * Wrap DevEngine in sync.Once.
  * Update placeholder engine image registry.
  * Add timeout to waiting on port from helper.
  * Write error logs to log output if set.
  * Appease linter.
  * Go back to embedded as default engineconn for now.
  * Split up dockerprovision connector into files.
  * Primitive dev test setup for engine image.
  * Shutdown helper when stdin is closed.
  * Fix engine image build of other OS bins.
  * Only set pdeathsig on Linux.
  * Remove volume from engine run; it's set via VOLUME anyways.
  * Include helper for each arch in engine image.
  * Add very basic garbage collection of engine+helper.
  * Update host env test to account for helper binary.
  * Add initial engine release step.
  * Initial Docker provision engineconn implementation.
  * build(deps): bump loader-utils from 2.0.2 to 2.0.3 in /website
  * ci: basic Python support
  * shim: unix->tcp API proxy
  * feat: improve connect function to use a callback.
  * feat: initializes GraphQL client on connect().
  * feat: replace Engine by dagger.Connect()
  * support dagger in dagger
  * docs: Update the dagger-cue installation steps
  * docs(go-git): authenticate against Git repositories
  * ci: multi-language support
  * ci: move magefile into an internal package
  * Appease linter for multiplatform snippets.
  * Fixup multiplatform snippet code.
  * Copy edit guide text, formatting and structure. Moved code into separate files. Updated sidebar.
  * API: git { commit }
  * Add docs for multiplatform support.
  * update note about git repo
  * simplify getting started guide to use native concurrency and local build
  * docs: go: remove unnecessary MkdirAll from snippets
  * docs: Add guide for new host API
  * ci: update add-issues-to-backlog workflow
  * Update 959738-get-started.md
  * add releasing instructions
  * build(deps): bump @svgr/webpack from 6.5.0 to 6.5.1 in /website
* Thu Dec  1 2022 kastl@b1-systems.de
- Update to version 0.3.3:
  Changelog (without SDK entries)
  * docs: go: remove ID() reference
  * fix test for IDless API
  * docs: Update the Go get started guide
  * docs: move snippets into get started directory
  * docs: move snippets into their own files
  * support exporting multi-platform images
  * File.export: take file path, not directory path
  * bring peace between copilot and linter
  * do not allow escaping workdir during export
  * File: add export
  * Container.export: redo without sessions
  * add Container { export }
  * router: move playground in internal package
  * router: switch to our own handler implementation
  * core: switch from graphql-go/graphql to dagger/graphql
  * WithNewDirectory: don't permit ../
  * add test for Directory.withFile mkdir
  * Directory: add withNewDirectory
  * Directory: withCopiedFile -> withFile
  * Add explicit qemu setup step to gha.
  * Add test for Windows image.
  * Add API for getting default platform.
  * Test cache mounts in platform execs.
  * Add field for reading platform to container.
  * Update test to include mounts of different platforms.
  * Test emulated execution of cross-compiled binary.
  * Add graphql scalar for Platform.
  * Support for multiplatform.
  * docs: update docusaurus to v2.2.0
  * explicitly test and handle mount clobbering
  * docs: Improve the Go get started
  * issue 3580: ref link to Dagger.Connect() (#3585)
  * go mod tidy (#3604)
  * replace mounts rather than stacking them
  * fix mount propagation causing repeated runs
  * Start: display if LogOutput is set
  * make progress field spookier
  * send docker auth logs to LogOutput
  * add progress config, default off when embedding
  * fix building container from subdirectory
  * ci: build into bin/
  * Handle lists of scalars in codegen.
  * Update go generate to use cloak binary.
  * Revert "allow wildcards in WithDirectory"
  * allow wildcards in WithDirectory
  * WithDirectory: copy directory contents only
  * Directory.withDirectory: support include/exclude
  * support include/exclude for host dir access
  * appease linter
  * roll back changes that were for newer buildkit
  * go back to vendored filesync impl
  * remove LocalDirs client config
  * dev cmd: support disabling host read/write access
  * map synced files to uid 0/0
  * simplify replace handling
  * update magefile
  * support bumping ahead of latest buildkit
  * evaluate symlinks in already-absolute paths
  * use merged buildkit dynamic-filesync
  * point to buildkit fork instead of vendoring
  * fix magefile
  * remove unused code
  * update godoc example
  * update a few queries that used workdir.read
  * simpler Host API
  * chore: fix import not being updated by goimports somehow
  * fix: log to stderr by default for cloak
  * feat(cli): dev can choose where to output log
  * docs: Add icon to docs pages for social sharing (#3579)
  * Add temporary blurb about go get -u.
  * Rename dagger binary to cloak
  * ci: build: match host platform/os
  * ci: lint using dagger
  * ci: build a static binary
  * ci: fix build for nested go.mod build
  * ci: replace previous build test
  * ci: put the build step in its own workflow
  * ci: add a GHA step for build:dagger
  * ci: fix go module download caching by using WithCopiedFile() instead of WithMountedFile()
  * feat: attempt to put go.mod dependencies in an early check
  * ci: update use of core API
  * build: update import path
  * fix: use the correct workdir to avoid Go modules problems
  * build: build dagger with mage
  * docs: fix markdown linter error
  * fix lint.yml yaml validation errors
  * Use more obscure name for shim meta mount.
  * build(deps): bump github.com/containerd/containerd from 1.6.8 to 1.6.9
  * Add note about why go mod replace is needed.
  * chore(deps): Bump amplitude-js from 8.21.1 to 8.21.2 in /website
  * docs: Fix punctuation in lists, update diagram
  * docs: Convert 2-page tutorial into  1-page
  * docs: Convert 2-page tutorial into  1-page
  * chore(deps): Bump github.com/spf13/cobra from 1.5.0 to 1.6.1
  * docs: update ps installer path
  * docs: Fixed links to previous version doc pages
  * disable secrets example for now
  * fix platform sensitive comment
  * you're not gonna believe this
  * more examples
  * add initial godoc examples + README
  * docs: remove scoop/choco until dagger-cue pkgs
  * ci: Hotfix if conditional in release-dagger-cue GHA workflow (#3535)
  * ci: Add release-dagger-cue GHA workflow to the main branch (#3533)
  * chore(typo): fix typo in DAG
  * Docs: adjust intro to fit website and README
  * chore: update README to fit website and docs
  * updated docs link
  * Add note about tidy
  * Clarify go install instructions needs to be in a go mod. (#3521)
  * Don't tidy; pull latest.
  * update LICENSE
  * Update Docs Posthog apikey
* Thu Dec  1 2022 kastl@b1-systems.de
- Update to version 0.3.2:
  * engine: bump SDK dependency into the future
  * sdk: go: bump engine dependency
* Thu Dec  1 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to 0.3.1:
  no changelog upstream
* Thu Dec  1 2022 kastl@b1-systems.de
- big Update to version 0.3.0:
  Changelog too big, please find it here:
  https://github.com/dagger/dagger/compare/v0.2.36...v0.3.0
* Wed Oct 12 2022 kastl@b1-systems.de
- Update to version 0.2.36:
  * build(deps): bump @svgr/webpack from 6.3.1 to 6.4.0 in /website
* Wed Sep 28 2022 kastl@b1-systems.de
- Update to version 0.2.35:
  * Fail auto-release if no changes since previous release (#3143)
  * Remove usage of go.#Test.package and go.#Build.package (#3010)
  * build(deps): bump github.com/google/go-cmp from 0.5.8 to 0.5.9 (#2999)
  * feat(project info): output available plans (#3139)
  * build(deps): bump sass from 1.54.9 to 1.55.0 in /website
  * build(deps): bump amplitude-js from 8.21.0 to 8.21.1 in /website
  * fix: Use brew install from core instead of tap (#3142)
* Wed Sep 14 2022 kastl@b1-systems.de
- Update to version 0.2.34:
  * feat: add tags support to `go` pkg (#3005)
  * Remove stdout tty check since dagger supports headless auth. (#3003)
  * build(deps): bump sass from 1.54.8 to 1.54.9 in /website
  * build(deps): bump amplitude-js from 8.20.1 to 8.21.0 in /website
  * docs: Disable medium-zoom on non-illustrative imgs
  * docs: Add Docusaurus medium-zoom plugin
  * build(deps): bump github.com/spf13/viper from 1.12.0 to 1.13.0 (#2998)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.2.33:
  * feat: improve windows install script, added optional parameters (#2903)
  * build(deps): bump @docusaurus/preset-classic in /website
  * build(deps): bump @docusaurus/core from 2.0.1 to 2.1.0 in /website
  * build(deps): bump amplitude-js from 8.20.0 to 8.20.1 in /website
  * build(deps): bump sass from 1.54.7 to 1.54.8 in /website
  * feat: fetch azure vault secret (#2987)
  * build(deps): bump github.com/rs/zerolog from 1.27.0 to 1.28.0 (#2983)
  * build(deps): bump sass from 1.54.5 to 1.54.7 in /website (#2988)
  * chore: use the standard personal bash completion's dir
  * chore: Add shell completion instructions to install.sh
  * fix: fix path to work correctly on debian derived system
  * feature: install completion script for bash, zsh and fish
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.2.32:
  * docs: update reference to jreleaser package
  * feat: aks specific helm action (#2914)
  * feat(universe): add jreleaser to alpha (#2979)
  * Update f44rm-how-it-works.mdx
  * Update 1242-install.mdx
  * Update 1242-install.mdx
  * build(deps): bump google.golang.org/grpc from 1.48.0 to 1.49.0 (#2974)
  * [Docs] Refactor Docs Redesign
  * docs: update cloud image + convert webp images to png (#2977)
  * build(deps): bump amplitude-js from 8.19.0 to 8.20.0 in /website
  * docs: fix typo for dagger cloud documentation (#2971)
  * build(deps): bump github.com/moby/buildkit from 0.10.3 to 0.10.4 (#2969)
  * website: use posthog to get users analysis path (#2968)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.2.31:
  * build(deps): bump sass from 1.54.4 to 1.54.5 in /website (#2965)
  * [Docs] Throw error on broken links
  * [Docs] Fix Navbar Styling on Mobile Devices
  * docs: UI Feedback Implementation (#2952)
  * docs: Add Debugging Section to the README (#2961)
  * [Docs] Update Bottom Pagination (#2960)
  * feat: added npm pkg (#2908)
  * fix: dagger project init <something> does not display useful command information #2538 (#2959)
  * build(deps): bump github.com/tliron/kutil from 0.1.61 to 0.1.62
  * ci: Do not run bats jobs in parallel
  * chore: Use a consistent approach to Terraform tests
  * fix: linter not working in git-worktrees
  * fix: make the URL work in github and locally (#2954)
  * added a release section (#2953)
  * Revert "fix: Increase Universe action timeout"
  * fix: Increase Universe action timeout
  * tests: Added test workflow for terraform custom docker image
  * fix: move version to #Image to prevent breaking custom docker.#Image
  * fix: Default to a specific Terraform version by default
  * feat: Add ability to use custom terraform version
  * Add go action to install/configure go into image (#2936)
  * docs: design pattern - how to build actions with customizable images (#2924)
  * docs: Add project update to local dev docs
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.2.30:
  * docs: Add FAQ on tests/secrets_sops.yaml (#2916)
  * build(deps): bump github.com/mattn/go-colorable from 0.1.12 to 0.1.13 (#2944)
  * ci: Disable GHA cache for Test Universe / Universe Tests
  * ci: Temporarily disable GHA cache for experimental universe tests
  * chore(universe/docker): rename p to path
  * fix(universe/docker): import path under alternative name
  * Mention in help that `do action` supports an optional number of subactions
  * chore: Bump bats to 1.7.0
  * chore: Fix yarn.lock
  * Hint that action is not optional for the do command
  * fix: dagger do help should indicate where to insert action name #2582
  * docs: fix link to todoapp example
  * chore(universe/docker): remove quotes around key path
  * chore(universe/docker): remove quotes around key test
  * fix(universe/docker): support exporting relative to working directory
  * docs: fix typo, shadowing not shodowing
  * refactor: use base pattern in goreleaser
  * [Docs] Update README explaining new UUID generation (#2934)
  * docs: env var reference (#2931)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.2.29:
  * [Docs] Fix Tutorial Card and Buttons (#2935)
  * added button to tutorial card (#2933)
  * fix: autorelease missing gh secret (#2930)
  * docs: Optimize Images (#2929)
  * build(deps): bump sass from 1.54.3 to 1.54.4 in /website
  * [Docs] Fix Navbar Styling and Links
  * fix: remove unnecessary left oauth2 comment (#2925)
  * fix: use correct oauth auth style (#2922)
  * feat: Terraform Workspace Action (#2919)
  * docs: fix broken links (#2915)
  * [Docs] Redesign (#2853)
  * fix: helm login action (#2896)
  * docs: Azure Pipelines Docs (#2904)
  * docs: fix typo in `what-is-cue` docs (#2906)
  * feat: Terraform Import Action (#2900)
  * AWS SAM package improvements (#2890)
  * build(deps): bump sass from 1.54.1 to 1.54.3 in /website
  * Change docs incremental index to use short UUID instead
  * add debug capabilities
  * docs: explain universe packages / clarify usage of sub-action term (#2897)
  * dont use pipe to let the script failed of a curl request was not successful
  * build(deps): bump sass from 1.54.0 to 1.54.1 in /website
  * Fix changes for homebrew-core PR (#2893)
  * ci: Add test-auto-release workflow
  * ci: Set tag-name explicitly for homebrew-core PR
  * implement aks auth
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.2.28:
  * ci: Open a homebrew-core PR when we release (#2888)
  * fix: LSP aliased import + single file error handling (#2889)
  * Add support for headless authentication
  * docs: Fix link to PR
  * docs: Expand on how to run the linters
  * docs: Make the section on links in docs clearer
  * chore: Update caniuse yarn dep
  * [Docs] bump docusaurus-preset-classic version
  * docs: rename plan docs title (#2880)
  * docs: raw strings use - example (#2882)
  * build(deps): bump react-social-login-buttons in /website
  * build(deps): bump @docusaurus/core from 2.0.0-rc.1 to 2.0.1 in /website
  * CUE docs gotchas updates
  * feat: new tty logger (#2751)
  * Update docs/guides/logdebug/1243-dagger-cloud-debugging.md
  * added clarification
  * refactor(golangci): split up action definitions into template and pre-configured image
  * docs: explain how to run single actions
  * fix: goreleaser key shadowing issue
  * fix: go cache race condition
  * fix: disjunction error on go.#Container + update tests accordingly
  * feat(universe/go): copy source instead of using a mount
  * test(universe/go): add missing go.sum
  * test(universe/go): don't write to /tmp for passing data between runs
  * test: add more way to avoid conflicts
  * test: fix go.#Build tests that rebase broke (deleting core import)
  * feat: deprecate package; with packages set, it takes the precedence
  * fix: add -e to "sh" invocation to error on the first one
  * chore: fix `go.#Test`
  * fix: add missing testutil package
  * fix: update from TomChv review
  * feat: deprecate go.#Test.package, add go.#Test.packages as [...string]
  * docs: clarify what data gets sent to dagger cloud
  * website: update embargoes compliance only for Crimea
  * build(deps): bump amplitude-js from 8.18.5 to 8.19.0 in /website
  * build(deps): bump sass from 1.53.0 to 1.54.0 in /website
* Wed Jul 27 2022 kastl@b1-systems.de
- Update to version 0.2.27:
  * docs: Jeremy edits
  * feat(lsp): update lsp import + fix incompatibilities
  * Send telemetry data about action cache status
  * docs: Dagger.#FS docs
  * aws/_scripts -> aws/scripts
* Tue Jul 26 2022 kastl@b1-systems.de
- Update to version 0.2.26:
  * implement helm upgrade action (#2807)
  * docs: add instructions for using SOPS  (#2852)
  * build(deps): bump @svgr/webpack from 6.3.0 to 6.3.1 in /website (#2840)
  * docs: Resolve Dagger version dynamically
  * docs: Add appropriate title to Jenkinsfile (#2848)
  * docs: Add appropriate title to Tekton YAML
  * docs: Add title to GitLab yaml
  * docs: Remove unecessary yaml header
  * docs: Add title to TravisCI yaml
  * docs: Add simple CircleCI example
  * chore: update go version in `#Build` test to 1.18
  * universe(go): revert of part of #2632
  * fix: ensure doppler works with file or config (#2833)
  * chore: updated the install link (#2834)
  * fix: absolute paths for plans (#2454)
  * feat(lsp): add `dagger lsp` command. (#2826)
  * feat: add Doppler support (#2831)
  * ci: Dependabot appends area/website label to /website bumps
  * website: remove cypress in absence of tests
  * build(deps): bump @svgr/webpack from 6.2.1 to 6.3.0 in /website
  * build(deps): bump terser from 5.10.0 to 5.14.2 in /website
  * bump up docusaurus preset classic
  * build(deps): bump @docusaurus/core in /website
* Thu Jul 21 2022 kastl@b1-systems.de
- Update to version 0.2.25:
  * fix: Use included wget instead of curl
  * Get telemetry pushing final states and action logs
  * build(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#2816)
  * feat: Add global auth env variables to `core.#Pull`
  * ci: print cue lint feedback for unformatted files
  * Mark runs failed when action cannot be found in plan
  * fix: Validator not detecting an edge case with valid FS reference
  * Keep go.opentelemetry.io/otel versions in sync with BuildKit
* Wed Jul 20 2022 kastl@b1-systems.de
- Update to version 0.2.24:
  * fix: broken CI due to alpha/aws/cdk test
  * Uploads evaluated plan to DC when validation fails.
  * ci: Use go.mod replaced CUE version for integration tests (#2801)
  * [Docs] Redirect deprecated Dagger Cloud page
  * build(deps): bump golang from 1.18.3-alpine to 1.18.4-alpine (#2792)
  * build(deps): bump google.golang.org/grpc from 1.47.0 to 1.48.0 (#2793)
  * universe: add uffizzi to dagger universe 🥳 (#2697)
  * docs: Improve “Project file organization” guide (#2773)
  * chore: Don’t create `cue.mod/usr` on init (#2787)
  * universe(x/kubectl): update kustomize with latest version (#2581)
  * Log core.Start output.  (#2561)
  * docs: Fix conflicting slug in docs (#2784)
  * fix: Use `bash.#Image` convention (#2775)
  * feat(universe): add goreleaser to alpha (#2758)
  * docs: Add Dagger Cloud discussion link in CTA
  * docs: Minor Dagger Cloud page rewords
  * docs: Remove tip dupe from Dagger Cloud docs
  * docs: Add how to disconnect the CLI from Cloud
  * docs: Fix Dagger Cloud CTA link
  * docs(install): fix windows path (#2780)
  * [Docs] Dagger Cloud CTA Routing Fix
* Sat Jul 16 2022 kastl@b1-systems.de
- Update to version 0.2.23:
  * ci: fix some linting
  * feat: use glamour in doc markdown rendering
  * build(deps): bump go.opentelemetry.io/otel from 1.4.1 to 1.8.0 (#2768)
  * website: Fix an error that was making docusaurus crashing when building
  * Update docusaurus theme on top of corex
  * Allow sending to DC invalid dagger plans that don't evaluate.
  * build(deps): bump @docusaurus/core in /website
  * docs: Move "vs" page to Core Concepts
  * Put the cue doc back to how it was as it seems to be the way cue wants it formatted
  * Small correction to make the cue valid
  * Grammer and little bit of key info missed
  * redirect user to the success page after authenticating
  * chore: Move Dagger comparison docs
  * Made the full pipeline a sub header to summary
  * Added header for full pipeline to make it easier to see in the the right sidebar
  * Added to sidebar and turned code snippets into files
  * Added 0.2 sidebar
  * Fixed lint issue
  * Spelling & grammer
  * Removed Gitleaks and completed rough outline
  * Rebased
  * refactor: apply coding style
  * refactor: add comments and clean code
  * clean: move azure package into x package
  * Add serverless package for azure
* Fri Jul  8 2022 kastl@b1-systems.de
- Update to version 0.2.22:
  * feat: support parsing and providing Pulumi outputs as secret (#2745)
  * chore: Remove Revision from GoReleaser
  * build(deps): bump clsx from 1.2.0 to 1.2.1 in /website (#2753)
  * fix: remove useless GIT_REVISION (#2755)
  * switch to strings.EqualFold for proxy env var
  * test: adds test for exec with http proxy
  * fix: prevent auth panic and handle auth race condition
  * add missing changes from https://github.com/dagger/dagger/pull/2414
  * chore: Bump Go to 1.18
  * feat: add support for HTTP, HTTPS proxy
  * Fix regression when printing 0.1 compat error msg
  * docs: add example of docker daemon interaction with dind
  * build(deps): bump clsx from 1.1.1 to 1.2.0 in /website
  * website: remove deprecated algolia config file (#2736)
  * Manually flush events in case of exiting without returning from function.
  * docs: add Dagger Cloud CTA
  * Add more permissive referrer header
  * [Docs] Sidebar UX Improvement
  * Send telemetry event when plan does not evaluate
  * build(deps): bump github.com/stretchr/testify from 1.7.4 to 1.8.0
  * docs: Fix Docker build argument name
  * Use new Docsearch Algolia app
  * docs: Migrate from docsearch-scraper to https://docsearch.algolia.com
  * docs: Fix image source on Docker build
  * fix: cue fmt
  * docs: remove noreferrer from dagger cloud links
  * (docs) Removed extra word `help` on `Contributing to Dagger` doc
  * build(deps-dev): bump cypress from 10.2.0 to 10.3.0 in /website
  * build(deps): bump github.com/hashicorp/go-version from 1.5.0 to 1.6.0
  * refactor(codecov): drop unnecessary import
  * build(deps): bump amplitude-js from 8.18.4 to 8.18.5 in /website
  * feat(universe): add codecov uploader to alpha
  * universe: bash: #RunSimple
  * build(deps): bump google.golang.org/grpc from 1.46.2 to 1.47.0
  * feat: restore doc generation for the whole library + index
  * feat: restore code to generate docs from a package name
  * feat: add python aws cdk package
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.2.21:
  * universe: php: composer: Removed string as argument for repository
  * universe: php: composer: Allow container to accept a docker.#image
  * universe: php: composer: Use env directly and restructure output to be one entry
  * chore: Back these files to the status that they have in the main branch
  * Fixes a somekind of markdown issue
  * Change to follow the style in the original guide
  * Fixes a markdown issue
  * Avoid to make more complex the build command adding the cache stuff
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#2699)
  * fix: Correct case for private definition per style (#2691)
  * Add a possible configuration to use dagger in TravisCi
  * [Docs] Categories UI improvement
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.7.4 (#2698)
  * build(deps): bump sass from 1.52.3 to 1.53.0 in /website
  * build(deps-dev): bump cypress from 10.1.0 to 10.2.0 in /website
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#2699)
  * fix: Correct case for private definition per style (#2691)
  * [Docs] Fix hyperlinks rendering inside admonitions
  * fix: visual fix
  * fix: redirect better visually
  * fix: Correct docs routes
  * print Dagger Cloud URL when starting plan
  * Effectively use embedding
  * enforce configuration mount
  * revert useless image configurations
  * universe: php: composer: Formatted code
  * universe: php: composer: Make image and repository configurable
  * universe: php: composer: Pulled apart image and container to seperate file and made package more extensible
  * feat: add support for aws sso credentials and container credentials relative uri
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.2.20:
  * Start w getting started (#2690)
  * docs: Provide more examples on `client: commands` and `platform` (#2668)
  * feat: Support Helm upgrade and custom namespace (#2674)
  * fix: correct GitHub camel case (#2678)
  * Use a worker pool to send telemetry data
  * docs: fix no-bare-urls rule
  * docs: add dagger cloud url to docs
  * chore: bump dagger patch version from 11 to 19 (#2652)
  * fix: added a variable to customize the binary in go.#Build
  * docs: Minor grammar fix for core concepts (#2675)
  * universe(x): move Scaleway pkg from x to alpha
  * universe(x): add experimental Scaleway package tests
  * universe(x): add experimental Scaleway package
  * fix: reverse `go.mod` change in merged PR
  * docs: Clarify git tag format when installing a package
  * updated the dagger cloud doc
  * docs: remove log-level insturctions for dagger cloud
  * docs: Add windows example in `cli.#Load` using socket
  * docs: Improve explanations in the docker guide's export admonitions
  * feat: Add install directory customization
  * Added package to use the package manager composer (#2620)
  * feat: allow custom image usage on go.#Build (#2632)
  * docs: Make contributing guidelines more visible
  * feat: add golangci to alpha universe (#2654)
  * fix: add additional flags to command (#2641)
  * build(deps-dev): bump concurrently from 7.2.0 to 7.2.2 in /website
  * add offline_access scope so refresh token flow can be performed
  * docs: Add docker package guide
  * chore: Add deprecation message
  * Add alpha and beta paths
  * build(deps-dev): bump cypress from 10.0.0 to 10.1.0 in /website
  * core: `#Mount` supports inline file
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.2.19:
  * chore: Add 'always' field to terraform.#Run from #2588 (#2618)
  * docs: fix dagger-cloud slug
  * docs: move dagger cloud under logdebug docs section
  * Add blurb about large changes to CONTRIBUTION.md
  * build(deps): bump sass from 1.52.1 to 1.52.3 in /website
  * docs: update engine version in dagger cloud docs
  * fix: make log level field names explicit
  * ci: disable old docs integration tests from the main plan
  * build(deps): bump github.com/rs/zerolog from 1.26.1 to 1.27.0
  * Add optional 'always' field to terraform.#Run, which will be passed to docker.#Run
  * build(deps-dev): bump cypress-localstorage-commands in /website
  * docs: link back to Source faq
  * fix: rename _op to _pull for better log UX
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.2.18:
  * bugfix: don't send 'run started' event on 'dagger do --help'
  * Add event to push action logs to Dagger Cloud
  * Rename ActionTransition to ActionTransitioned
  * Revert "Rename LogEmitted to Logger"
  * Rename LogEmitted to Logger
  * code: revert Data field type back to Properties in Event struct
  * Remove unused var
  * Remove redundant TODO
  * Replace all occurences of targetPath.String()
  * Track plan start & end via events ONLY, not logs
  * Send logs as strongly typed events ONLY
  * Rename ActionUpdated to ActionTransition
  * Reuse variable in otel tracer
  * Use an empty interface for event data
  * Revert StateRunning to StateComputing
  * Send strongly typed cloud logs, via Telemetry (not Logger)
  * Track run state changes explicitly, via Telemetry
  * Add experimental --telemetry-log flag
  * Cleanup event errors & test
  * action events
  * universe: new namespace universe.dagger.io/alpha
  * docs: add "how to submit a help request" section
  * build(deps): bump github.com/stretchr/testify from 1.7.1 to 1.7.2 (#2584)
  * docs(faq): explain field shadowing
* Thu Jun  9 2022 kastl@b1-systems.de
- Update to version 0.2.17:
  * website: update to a major version of Cypress
  * docs: Cloud docs fixes and version note
* Mon Jun  6 2022 kastl@b1-systems.de
- Update to version 0.2.16:
  * Add initial docs for Dagger Cloud
  * Add start, stop and error events for plan execution
  * x/pulumi: add support for stack outputs
  * x/pulumi: fix PULUMI_STACK env var use
* Mon Jun  6 2022 kastl@b1-systems.de
- Update to version 0.2.15:
  * Initial support for logging the plan
  * build(deps): bump golang from 1.18.2-alpine to 1.18.3-alpine (#2562)
  * dagger do: log command args and target action
  * FAQs to guides with subcategories (#2558)
  * Support signaling core.Start execs.
  * website: bump up docusaurus preset-classic + netlify node version
  * build(deps): bump amplitude-js from 8.18.3 to 8.18.4 in /website
  * website: make quotes visible in dark mode
  * build(deps): bump @docusaurus/core in /website
* Sat Jun  4 2022 kastl@b1-systems.de
- Update to version 0.2.14:
  * telemetry: Fix flaky run ID
  * endpoint: switch from dagger.io to dagger.cloud
  * feat(universe): add experimental kustomization (#2531)
  * Improve Secrets docs (#2541)
  * build(deps): bump gopkg.in/yaml.v3 from 3.0.0 to 3.0.1 (#2534)
  * Default user to "root:root" rather than "root".
  * build(deps-dev): bump cypress-localstorage-commands in /website
  * bugfix: add image.config.workdir support to docker.#Copy
* Wed Jun  1 2022 kastl@b1-systems.de
- Update to version 0.2.13:
  * website: make code in hyperlinks visible
  * Fix outputs2 marshal error
  * Remove Ginkgo suite for version
  * Do not use the Cloud logger if there are no credentials
  * Print requests too
  * Use runId instead of run_id
  * Print events, json & responses
  * Send log events async using TelemetryLite
  * Send outputs when run finishes
  * Add a more details to all events (logs) sent to the cloud
  * Timeout all API requests after 10 seconds
  * Extract engine ID functionality
  * Send all logs to API if logged in
  * Start implementing events stream to the API
  * feat: add docker.#Scratch image
  * build(deps): bump github.com/spf13/viper from 1.11.0 to 1.12.0 (#2520)
  * Simplify version tests
  * Use only Sprintf, don't combine with string concatenation
  * Convert version tests to use stretchr/testify
  * core.#Nop: fix output to be properly generated
  * Clarify how to safely export binary data in docs.
  * telemetry: event type system
  * Use version Short() or Long() across the codebase
  * docs: Explain how to use `core.#Source` (#2525)
  * fix(docker.#Image): correctly verify files (#2524)
  * doc: clean up wording + removed install instructions
  * doc: split install steps to standalone page
  * Enable debug logs for the default buildkitd-worker.
  * chore: remove todoapp test
  * Docs: getting started: use new todoapp repo
  * chore: remove examples from universe
  * ci: Split Experimental tests from Universe tests
  * build(deps): bump amplitude-js from 8.18.2 to 8.18.3 in /website
  * ci: port TESTDIR= feature for universe tests
  * ci: use normal binary for universe and docs integration tests
  * ci: moving universe and docs integration tests to the dagger CI plan
  * build(deps): bump sass from 1.51.0 to 1.52.1 in /website
  * build(deps-dev): bump cypress from 9.6.1 to 9.7.0 in /website
* Mon May 30 2022 kastl@b1-systems.de
- Update to version 0.2.12:
  * Keep the _api_test command until we have a higher-level integration
  * Capitalise Dagger in login/logout commands
  * Remove redundant http server
  * Remove API keys auth message
  * Link to the app which we got the ClientID from
  * analytics: remove git origin duplicates
  * fix: Bump `dagger.io` package requirement
  * ci: use prod dagger binary in universe tests
  * feat: universe: new and improved yarn package
  * experimental: fix and improve custom yarn package (#2480)
  * rename telemetry to analytics
  * build(deps): bump github.com/hashicorp/go-version from 1.4.0 to 1.5.0
  * fix: Default to json when printing action outputs in a non-tty environment
  * docs: Update "Handling action outputs" docs  (#2478)
  * doc: document cue fmt -s in the package coding style
  * docs: bump dagger version to v0.2.11 (#2471)
  * feature: Add ability to filter universe tests
  * feature: Add apt package to universe
  * fix: Add type to `#DecodeSecret`’s `output`
  * gitpod: mark /src directory as safe to use
  * Experimental: modified version of Kambui Nurse's spectral package
  * authenticated client support
  * primitive auth support
  * feat: Add 1password package
* Fri May 20 2022 kastl@b1-systems.de
- Update to version 0.2.11:
  * build(deps): bump google.golang.org/grpc from 1.46.0 to 1.46.2 (#2458)
  * Bump Docusaurus up to 2.0.0-beta.20 (#2463)
  * core: add `#Rm` core action (#2422)
  * telemetry: include the git repository
  * build(deps-dev): bump concurrently from 7.0.0 to 7.2.0 in /website
  * docs: bypass `Permission denied` error on cloning repo (#2387)
  * Add GitHub Codespaces support (#2217)
  * feat: Add debian (#2433)
  * build(deps): bump amplitude-js from 8.18.1 to 8.18.2 in /website
  * feat: Add sam package
  * docs: making-reusable-package
  * docs: project-file-organization
  * ci: add plan for viewing Jaeger CI traces locally
  * Set trace name with bats test name.
  * ci: add tracing support to integration tests.
  * Downgrade opentelemetry to match Buildkit's version.
  * docs: document usage with buildkit unix socket
  * build(deps): bump golang from 1.18.1-alpine to 1.18.2-alpine
  * feat: export secrets with `docker.#Run`
  * ci: Pass cache env vars through to integ tests.
  * ci: set log format to plain
  * feat: add Gitpod support
  * fix: Course correct on `project update` consistency
  * feat: Use `client: filesystem` path as a default
  * docs: Add more installation options for Windows
  * build(deps-dev): bump cypress from 9.6.0 to 9.6.1 in /website
  * universe: add test with kustomization
  * universe: add `#Delete` definition to experimental kubernetes package
  * Add yaml content to the markdown file and remove external tekton file to fix the lint issue
  * docs: rename tekton file
  * docs: use dagger values
  * docs: dagger version and netlify team as parameters
  * docs: dagger action as param + clarify name parameter
  * docs: remove useless commands
  * docs: Update ci-environment doc to add tekton example
  * docs: Getting started with Tekton
* Fri May 13 2022 kastl@b1-systems.de
- Update to version 0.2.10:
  * Improve start/stop test.
  * ci: addresses @aluzzardi comments: move to test subkey, compile dagger bin with -race
  * universe: python: Use official python image
  * build(deps): bump github.com/moby/buildkit from 0.10.2 to 0.10.3
  * universe: Add kubernetes package
  * ci: bump github action to latest (#2411)
  * plan: unquote actions names
  * docs: Fix persistent cache doc id
  * ci: use same source everywhere
  * ci: move core-integration tests to dagger
  * ci: integration: fixed sops dependency + added jq
  * ci: test: disabled file check that relies on a directory outside of the tests directory
  * ci: added docker client dependency and reworked the packages+mods install
  * ci: added dagger binary to bats
  * ci: cue fmt
  * ci: implemented bats support
  * ci: ignore build output dir
  * ci test: split each dagger do to own test name
  * ci: sops cleanup: point to the key directly rather than copying it around (#2400)
  * Update docs to 0.2.9
  * docs: Fix docker cache-registry container port
  * fix: Missing import, uid & type in experimental kubernetes package
  * feat: initial kubectl apply
  * Upgrade to cue v0.4.3
  * docs: Add new commits prefix `fix` and `feat`
  * Fail if unknown flag is specified (#2391)
  * universe: Add Terraform package (#2192)
  * docs: Reverse doc orders and improve docs
  * feat(universe-x): ansible package
  * docs: Add tests file for persistent cache
  * docs: Fix typo found
  * docs: Add documentation on GitHub action cache export
  * docs: Add documentation on registry cache export
  * docs: Add documentation on local cache export
* Wed May  4 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.9:
  * Don't redact secret if it's an empty string.
  * Fix tty log panic issue
  * Revert specific case to handle dockerfile actions
  * Support for async start/stop execs.
  * Use progress group to track components of vertices.
  * adding kapp as package (@renuy)
  * cache: Error out if GHA used w/out token or url.
  * check vendored package versions and prompt users to upgrade
  * client: use lock file to dedupe buildkitd creation.
  * core.#Nop: fix return value (@aluzzardi)
  * do: add experimental --dry-run flag (@aluzzardi)
  * feat: Allow marking client: env variables as optional
  * feat: Print action outputs to console
  * feat: Use client: network address as a default
  * feat: add kustomize package (@lyzhang1999)
  * feat: improved yarn package (experimental)
  * feat: kapp support (@renuy)
  * feat:add discord webhook support (@hardy4yooz)
  * fix plan validation for generated fields (@aluzzardi)
  * fix: Fix DecodeSecret output type (@helderco)
  * fix: Fix generated attributes (@helderco)
  * fix: Remove entrypoint from bash.#Run (@helderco)
  * improve OpenTracing coverage (@aluzzardi)
  * link to core actions reference docs rather than repo
  * plan validation: fix structure navigation (@aluzzardi)
  * solver: fix duplicate logs on export (@sipsma)
  * tty logger: fix group status for hidden sub-actions
* Tue Apr 26 2022 kastl@b1-systems.de
- Update to version 0.2.8:
  * ci: fix cache key creation on main (#2307)
  * plan validation: abort if structures are not concrete
  * ci: fix typo in bin output field
  * build(deps-dev): bump cypress from 9.5.4 to 9.6.0 in /website
  * ci: fix dockerfile (#2288)
  * feat: pull-policy
  * ci: scope cache to enhance speed
  * fix: update tests with new package/binary name
  * fix: rename duplicates Go modules
  * fix: should show cue error details when WriteFile contents not set
  * universe: Set bash.#Run entrypoint to `/bin/bash`
  * docs: Fix contributing guide link in README
  * validate plan concreteness before execution
  * ci: stop printing all cue files when linting
  * build(deps): bump google.golang.org/grpc from 1.45.0 to 1.46.0
  * Add youtube video embed
  * Update Jenkinsfile
  * Fix FAQ broken links
  * Avoid duplicate StringSlices when parsing flags
  * Fixed bug for path without any actions
  * docs: Update multi-stage example
  * docs: Add embedding sample
  * docs: Add embedding explanation
  * docs: add connhelper instructions
  * chore: Finish renaming service to socket
  * chore: Rename service to socket
  * filter out commandConn.CloseRead warning log message
  * Add rust to universe
  * docs: Update version
  * ci: add lint error header in log
  * ci: run go unit tests from the dagger plan
  * build(deps): bump sass from 1.50.0 to 1.50.1 in /website
  * docs: discard opentracing doc, using opentelemetry
* Wed Apr 20 2022 kastl@b1-systems.de
- Update to version 0.2.7:
  * docs: fixed misleading example code
  * Improve tty error logging when buildkit vertex is unknown (#2188)
  * docs: avoid multiple packages in examples
  * Docs: fix index
  * Docs: split introduction & getting started sections
  * feat: support helm
  * `dagger do` action options flags
  * core.#WriteFile: default permissions to 0o644
  * enable kubernetes and podman connection drivers
  * universe: netlify: replace curl-based wrapper with cli
  * docs: Add types reference
  * chore!: Make `dagger.#Address` private
  * chore: Quote value in error
  * build(deps): bump async from 2.6.3 to 2.6.4 in /website
  * ci: Deploy todoapp with dev dagger AND ALSO latest 0.2.x release
  * docs: update github actions workflow example
  * docs: add to the sidebar
  * docs: fix some PR suggestions
  * docs: fix go-ci guide slug and add file title
  * docs: add simple Go guide
  * docs: docs: guide - default values cue
  * docs: Implement FAQ page, default values in Cue + fix sidebar and titles
  * docs: guide - chaining actions
  * docs: guide - always execute an action
  * docs: guide - logs options in Dagger
  * docs: guide - empty buildkit cache doc
  * docs: Mention macOS ARM vs Intel Homebrew dagger install path diff
  * Docs: move "migrate to 0.1" to a guide
  * Docs: rephrase article 1216
  * Docs: remove duplicate entry in sidebar
  * build(deps): bump github.com/spf13/viper from 1.10.0 to 1.11.0
  * build(deps): bump golang from 1.16.15-alpine to 1.18.1-alpine
  * ci: dependabot: change label
  * build(deps): bump go.opentelemetry.io/otel/trace from 1.6.2 to 1.6.3
  * docs: Add guide to showcase handling outputs
  * chore: explicit codeowners for CLI
  * website: hardcode version banner for 0.1 docs
  * fix: explicit dagger project usage
  * docs: Move contribution guide to docs website
  * filter out useless commandConn.CloseWrite warning message
  * Allow to specify template when running `dagger project init`
  * ci: fix CUE linter
  * chore: separate review rotation on universe.dagger.io/x/
  * chore: explicit codeowners for the CODEOWNERS file
  * feat: add lua universe package and stylua command to fmt check
  * docs: add missing import to example AddHello action (#2154)
  * universe: python: allow custom path to python
  * docs: Add Jenkins CI doc. Fixes #2067
  * build(deps): bump github.com/docker/buildx from 0.8.1 to 0.8.2
  * fix: include env insideo of container on .NET publish
  * feat: support .NET
  * removed project init from the ci and pinned update version
  * fixed the sample github action in the documentation
* Thu Apr 14 2022 kastl@b1-systems.de
- Update to version 0.2.6:
  * docs: remove dead links. References doesn't exist anymore
  * website: Increase broken links checking
  * feat: Convert home relative paths in cache entries
  * fix: update install link
  * ci: add new issues to backlog project
  * Fix default client env when var is set (#2128)
  * website: update code block font
  * build(deps-dev): bump cypress from 9.5.3 to 9.5.4 in /website
  * feat: Allow default values in `client: env` (#2122)
  * docs: Link to markdown files
  * docs: Package coding style
  * Update 1221-action.md
  * chore: update clientfilesystemread.go Signed-off-by: rrylee <rrylee1994@gmail.com>
  * Docs: Add docs to sidebar
  * Docs: guides/1225-pushing-plan-dependencies
  * Docs: 1224-self-signed-certificates
  * Docs: 1223-custom-buildkit improvement
  * chore: Fix typo
  * Docs: guides: customizing your buildkit installation
  * client: fix deadlock when connect to buildkitd fails
  * Docs: move draft articles to "guides"
  * Docs: move CLI telemetry to guides section
  * Docs: fix formatting in article 1221
  * ci: cue linter: include all CUE files
  * tests: Adding update to project info for negative test case
  * Docs: shorten title of article 1205
  * build(deps): bump github.com/moby/buildkit from 0.10.0 to 0.10.1
  * build(deps): bump go.opentelemetry.io/otel/exporters/jaeger
  * ci: Use default CODEOWNERS for docs sidebar
  * build(deps): bump sass from 1.49.11 to 1.50.0 in /website
  * Docs: core actions reference
  * build(deps): bump go.opentelemetry.io/otel/sdk from 1.6.1 to 1.6.2
  * universe: python: Update to 0.2
  * Docs: core concepts: actions
  * Docs: new category "guides"
  * test: Update project info test to fix issue
  * test: Fixing project info integration test
  * ci: lint dagger using dagger
  * test: Update project info command to pass lint and test to make sure TEMPDIR is there
  * Docs: add content to 1205: "building container images"
  * feat: Adding project info command to find where project is located
  * build(deps): bump amplitude-js from 8.18.0 to 8.18.1 in /website
  * docs: improve comment wording
  * Add global --experimental flag to gatekeep some features
  * Add experimental way to set a target platform when building
  * fix: wrap the error
  * fix: add full error handling after os.Stat
  * ci: Group changelog entries
* Wed Apr  6 2022 kastl@b1-systems.de
- Update to version 0.2.5:
  * temporarily disable the `platform` field.
  * Automatically set target platform based on client architecture
  * ci: Remove release.yml workflow
  * ci: fix auto-release secrets
  * ci: fix workflow secret names
  * Remove incorrect installer documentation
  * ci: move ci infra top-level
  * ci: lint markdown files
  * ci: lint shell
  * ci: improve dogfood configuration
  * ci: use dagger from source
  * universe: go: add golangci-lint support
  * task: source: fix vertex name
  * client filesystem: remove .dagger from default exclusion
  * universe: go: improve cache management
  * universe: go: do not hardcode default platform
  * docs: add tip for support symlink with git on Windows
  * docs: fix Europa wording on migration docs (#2032)
  * build(deps): bump sass from 1.49.10 to 1.49.11 in /website
  * refactor!: Move image definitions to `dagger/core`
  * Fix mounts in `cli.#Run`
  * ci: Add full changelog to release notes
  * ci: Add changelog exclusion for chores
  * ci: Use github for the changelog
  * docs: Correctly capitalize GitLab
  * docs: Correctly capitalize GitHub
  * universe: go: add git by default in go.#Image
  * Adds support for 32bit armv7 devices.
  * docs: s/poject/project/ in go-docker-swarm.md
  * docs: fix broken link in universe README.md
  * Fix typo (#1953)
  * fix: tidy up a little
  * fix: appease the linter
  * build(deps): bump amplitude-js from 8.17.0 to 8.18.0 in /website
  * Report error if FS is incorrectly handled on client filesystem read
  * feat: add Pulumi support
  * website: remove navbar schedule link
  * website: update favicon
  * Copied Dagger vs documentation to Europa.
  * copy: support for include/exclude
  * docs: Remove curl dependency when installing on Windows
  * Prevents files to be used as input of dagger.#FS
  * ci: add CODEOWNERS
  * build(deps): bump sass from 1.49.9 to 1.49.10 in /website
  * Fix export cache issue
  * use h2 title instead of h3 + fix code css
  * bump up docusaurus preset classic theme
  * reduce main wrapper padding and sidebar width to avoid horizontal scrolling
  * doc: remove the bash syntax highlighting
  * Display getting started as the index page
  * Update install procedure
  * Docs Update:1200-local-dev.md build/index.html -> _buld/index/html
  * Changed underscore position in hidden definition.
  * Hid DefaultVersion definition.
  * Changed test name due to conflict with bash tests.
  * ci: Fix key copying
  * ci: Unify keys and add private key for testing purposes
  * docs: add getting started gitlab ci configuration
  * doc: Improve wording on “Go on Docker Hub” use case
  * Go on Docker Swarm
  * Exclude docs from universe and integration tests
  * fix: :adhesive_bandage: website: use docusaurus context
  * fix: :adhesive_bandage: create a dev script with REACT_APP_AMPLITUDE_ID empty
  * website: add environment var to avoid crash issue
  * update references to alpha.dagger.io
  * Move Dagger 0.1 link back to the bottom
  * Fix Go on DockerHub id & filename + remove from sidebar
  * examples: set as vendored to not count in repository stats
  * docs: added page to sidebar
  * docs: added a page about CLI telemetry
  * build(deps-dev): bump cypress from 9.5.2 to 9.5.3 in /website
  * build(deps): bump @docusaurus/core in /website
* Fri Apr  1 2022 Johannes Kastl <kastl@b1-systems.de>
- new package dagger: A portable devkit for CI/CD pipelines
